/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.commons.annotation;

import java.lang.annotation.Annotation;
import java.lang.reflect.Modifier;
import java.util.stream.Collectors;

import org.atteo.classindex.ClassIndex;

import com.google.common.collect.Streams;

/** Wrapper to retrieve annotated classes. */
public class ClassIndexUtils {

	/**
	 * Returns all classes annotated with the given annotation. This is workaround
	 * for https://github.com/atteo/classindex/issues/54.
	 */
	public static Iterable<Class<?>> getAnnotated(Class<? extends Annotation> annotation) {
		Iterable<Class<?>> annotated = ClassIndex.getAnnotated(annotation);
		return Streams.stream(annotated).filter(clazz -> clazz.isAnnotationPresent(annotation))
				.collect(Collectors.toList());
	}

	/**
	 * Returns all subclasses of the given super class (provided that this class has
	 * been annotated with {@link org.atteo.classindex.IndexSubclasses} that are
	 * non-abstract and not interfaces.
	 */
	public static <T> Iterable<Class<? extends T>> getConcreteSubclasses(Class<T> superClass) {
		return Streams.stream(ClassIndex.getSubclasses(superClass))
				.filter(clazz -> !Modifier.isAbstract(clazz.getModifiers())).collect(Collectors.toList());
	}

}
