/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.commons.service;

/**
 * Enumeration of MIME types used/supported. This is by no means meant to cover
 * all existing MIME types, but only those used in this application.
 */
public enum EMimeType {

	/** Plain text. */
	PLAIN("text/plain"),

	/** XML text. */
	XML("text/xml"),

	/** JSON code. */
	JSON("application/json"),

	/** Url encoded form data. */
	URL_ENCODED_FORM_DATA("application/x-www-form-urlencoded");

	/** The type. */
	private final String type;

	/** Constructor. */
	EMimeType(String type) {
		this.type = type;
	}

	/** Returns the type string. */
	public String getType() {
		return type;
	}

}
