/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.commons.utils;

import java.lang.ref.WeakReference;
import java.util.Collections;
import java.util.Map;
import java.util.WeakHashMap;

/**
 * Base class for object pools. Please note that T must have proper hashCode()
 * and equals() methods.
 */
public class ObjectPool<T> {

	private final Map<T, WeakReference<T>> objectPool = Collections.synchronizedMap(new WeakHashMap<>(100000));

	/**
	 * Checks whether we already have an object in the pool that is equal to the
	 * given one. If such an object already exists, it is returned, otherwise the
	 * given object is interned and returned.
	 */
	public T intern(T object) {
		WeakReference<T> cached = objectPool.get(object);
		if (cached != null) {
			T value = cached.get();
			if (value != null) {
				return value;
			}
		}
		objectPool.put(object, new WeakReference<>(object));
		return object;
	}

}
