/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide;

import org.eclipse.core.resources.IProject;
import org.eclipse.jface.window.Window;
import org.eclipse.ui.dialogs.PreferencesUtil;

import com.teamscale.ide.client.NamedServerDetails;
import com.teamscale.ide.eclipse.EclipseIds;
import com.teamscale.ide.eclipse.util.ui.WorkbenchUtils;
import com.teamscale.ide.prefs.ServerDetailsDialog;

/**
 * Util functions for working with eclipse.
 */
public class EclipseUtils {

	/**
	 * Opens the ServerDetailsDialog and returns a server or <code>null</code>.
	 */
	public static NamedServerDetails openServerDetailsDialog(String text) {
		return openServerDetailsDialog(text, false);
	}

	/**
	 * Opens the ServerDetailsDialog and returns a server or <code>null</code>.
	 */
	public static NamedServerDetails openServerDetailsDialog(String text, Boolean allowToAddDisabledServer) {
		ServerDetailsDialog dialog = new ServerDetailsDialog(WorkbenchUtils.getActiveShell().orElse(null), text,
				allowToAddDisabledServer);
		NamedServerDetails server = null;
		if (dialog.open() == Window.OK) {
			server = new NamedServerDetails(dialog.getServerName(), dialog.getServerUrl(), dialog.getUsername(),
					dialog.getPassword(), dialog.isEnabled(), dialog.isTrustAllCertificates());
		}
		return server;
	}

	/** Opens the Teamscale project preference page. */
	public static void openTeamscaleProjectPreferencePage(IProject project) {
		PreferencesUtil
				.createPropertyDialogOn(WorkbenchUtils.getActiveShell().orElse(null), project,
						EclipseIds.PropertyPages.TEAMSCALE, new String[] { EclipseIds.PropertyPages.TEAMSCALE }, null)
				.open();
	}
}
