/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide;

import org.eclipse.core.commands.Command;
import org.eclipse.core.commands.State;
import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.ui.PlatformUI;
import org.eclipse.ui.commands.ICommandService;
import org.eclipse.ui.handlers.RegistryToggleState;
import org.eclipse.ui.plugin.AbstractUIPlugin;
import org.osgi.framework.BundleContext;

import com.teamscale.ide.eclipse.EclipseIds;
import com.teamscale.ide.ui.images.ETeamscaleImage;

/**
 * Activator.
 */
public class TeamscaleIDEActivator extends AbstractUIPlugin {

	/** Shared instance. */
	private static TeamscaleIDEActivator plugin;

	@Override
	public void start(BundleContext context) throws Exception {
		super.start(context);
		plugin = this;
	}

	@Override
	public void stop(BundleContext context) throws Exception {
		plugin = null;
		super.stop(context);
	}

	/** Returns the shared instance. */
	public static TeamscaleIDEActivator getDefault() {
		return plugin;
	}

	/** Returns whether the toggle command with the given ID enabled. */
	public static boolean isCommandEnabled(String commandId) {
		ICommandService commandService = ICommandService.class
				.cast(PlatformUI.getWorkbench().getService(ICommandService.class));
		Command command = commandService.getCommand(commandId);

		State state = command.getState(RegistryToggleState.STATE_ID);
		if (state == null) {
			// E. g. when this runs the first time after plug-in installation
			return false;
		}

		return (Boolean) state.getValue();
	}

	/**
	 * Returns an image descriptor for the image file at the given plug-in relative
	 * path.
	 */
	public static ImageDescriptor getImageDescriptor(String path) {
		return imageDescriptorFromPlugin(EclipseIds.PLUGIN, path);
	}

	/** {@inheritDoc} */
	@Override
	protected void initializeImageRegistry(ImageRegistry registry) {
		ETeamscaleImage.registerImages(registry);
	}
}
