/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.client;

import com.teamscale.ide.findings.view.FindingsMarkerView;

/**
 * A job that checks whether a server is reachable again, while it is
 * temporarily disabled. If it is reachable, error messages from the
 * FindingsMarkerView will be removed and the status entry in the
 * TeamscaleServerStatusRegistry is set appropriately.
 */
public class CheckTemporarilyDisabledConnectionJob extends ConnectionValidationJob {
	/** Creates a new job for the given server. */
	public CheckTemporarilyDisabledConnectionJob(NamedServerDetails serverDetails) {
		super("Checking server connection...", serverDetails, new FinishedCallback());
	}

	/** A callback that is executed when the job has finished. */
	private static class FinishedCallback implements ConnectionValidationJob.ValidationFinishedCallback {

		/** {@inheritDoc} */
		@Override
		public void execute(NamedServerDetails serverDetails, boolean isReachable, String errorMessage) {
			String symbolicName = serverDetails.getSymbolicName();

			ETeamscaleServerStatus newStatus = ETeamscaleServerStatus.REACHABLE;
			// if the server is still unreachable, we keep the original
			// temporarily disabled status
			if (!isReachable) {
				newStatus = ETeamscaleServerStatus.TEMPORARILY_DISABLED;
			} else {
				FindingsMarkerView.removeErrorMessage();
			}

			TeamscaleServerStatus.getInstance().setStatus(symbolicName, newStatus);
		}

	}
}
