/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.client;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.commons.service.client.ServerDetails;

/**
 * Adds a "symbolic name" to {@link ServerDetails} that is used to lookup the
 * ServerDetails object for an Eclipse project as configured by the user.
 */
public class NamedServerDetails extends ServerDetails {

	/** A symbolic name for the connection settings. */
	private final String symbolicName;

	/** Whether this server is currently enabled. */
	private Boolean enabled;

	/** Whether this server is currently enabled. */
	private final boolean trustAllCertificates;

	@JsonCreator
	public NamedServerDetails(@JsonProperty("symbolicName") String symbolicName, @JsonProperty("url") String url,
			@JsonProperty("username") String username, @JsonProperty("password") String password,
			@JsonProperty("enabled") boolean enabled,
			@JsonProperty("trustAllCertificates") boolean trustAllCertificates) {
		super(url, username, password);
		this.symbolicName = symbolicName;
		this.enabled = enabled;
		this.trustAllCertificates = trustAllCertificates;
	}

	/** Returns the symbolic name. */
	public String getSymbolicName() {
		return symbolicName;
	}

	/** Sets enabled. */
	public void setEnabled(boolean enabled) {
		this.enabled = enabled;
	}

	/** Returns enabled. */
	public boolean isEnabled() {
		// When updating the eclipse plugin from an older version, the enabled
		// flag is not stored in the eclipse preferences and will therefore be
		// set to null. If this happens, the server should be enabled by
		// default.
		if (enabled == null) {
			enabled = true;
		}
		return enabled;
	}

	public boolean isTrustAllCertificates() {
		return trustAllCertificates;
	}
}
