package com.teamscale.ide.client.adt;

import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.core.resources.IProject;

import com.google.common.base.Strings;

/**
 * Maps a ADT URI for class additions that matches the given pattern with the
 * help of the given template to a Teamscale URI.
 * <p>
 * It is expected that the pattern has a named group "name" and that the template 
 * has exactly two positions to insert the given name into with string formatting.
 */
class AdtClassAdditionsUriMapper implements IAdtUriMapper {

	private static final Logger LOGGER = LogManager.getLogger();

	/** The maximum class name length to pad the name with '='. */
	private static final int MAX_CLASS_NAME_LENGTH = 30;
	
	private static final String GROUP = "name";

	private final Pattern pattern;
	
	private final String teamscaleUriTemplate;
	
	AdtClassAdditionsUriMapper(String pattern, String teamscaleUriTemplate) {
		this.pattern = Pattern.compile(pattern);
		this.teamscaleUriTemplate = teamscaleUriTemplate;
	}
	
	@Override
	public Optional<String> map(String uri, IProject project) {
		LOGGER.traceEntry(null, uri, project);
		Matcher matcher = pattern.matcher(uri);
		if (!matcher.matches()) {
			return LOGGER.traceExit(Optional.empty());
		}
		String name = AdtUriMappingUtils.convertFileNameToAbapName(matcher.group(GROUP));
		return LOGGER.traceExit(Optional.of(String.format(teamscaleUriTemplate, name, 
				name + Strings.repeat("=", MAX_CLASS_NAME_LENGTH - name.length()))));
	}

}
