package com.teamscale.ide.client.adt;

import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.core.resources.IProject;

/**
 * Maps a URI for fugr paths to a Teamscale URI.
 */
class AdtFugrPathUriMapper implements IAdtUriMapper {

	private static final Logger LOGGER = LogManager.getLogger();
	
	private static final String NAME_GROUP = "name";

	private static final Pattern PATTERN = Pattern
			.compile("/sap/bc/adt/functions/groups/(?<name>.+)/source/main");
	
	private static final String TEAMSCALE_URI_TEMPLATE = "FUGR/%s/%s.abap";
	
	@Override
	public Optional<String> map(String uri, IProject project) {
		LOGGER.traceEntry(null, uri, project);
		Matcher matcher = PATTERN.matcher(uri);
		if (!matcher.matches()) {
			return LOGGER.traceExit(Optional.empty());
		}
		String functionGroupName = AdtUriMappingUtils.convertFileNameToAbapName(matcher.group(NAME_GROUP));
		return LOGGER.traceExit(Optional.of(String.format(TEAMSCALE_URI_TEMPLATE, functionGroupName,
				AdtUriMappingUtils.getFunctionGroupNameWithPrefix(functionGroupName, "SAPL"))));
	}
}
