package com.teamscale.ide.client.adt;

import java.io.UnsupportedEncodingException;
import java.net.URLDecoder;
import java.nio.charset.StandardCharsets;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import com.google.common.base.Preconditions;
import com.google.common.base.Strings;

/**
 * Utils for ADT URI to Teamscale mapping.
 */
public class AdtUriMappingUtils {

	private static final Pattern FUNCTION_GROUP_NAME_PATTERN = Pattern.compile("(?<customNamespace>!.*!)?(?<name>.*)");
	private static final Pattern FUNCTION_GROUP_NAME_PATTERN_IN_ADT = Pattern.compile("(/(?<customNamespace>.*)/)?(?<name>.*)");
	
	/**
	 * Replaces the special characters to get a valid file name. See also
	 * org.conqat.engine.abap.AbapUtils.java.
	 */
	public static String convertFileNameToAbapName(String urlFragment) {
		try {
			return URLDecoder.decode(urlFragment, StandardCharsets.UTF_8.name()).replace("!", "#excl#")
					.replace("/", "!").replace("\\", "#rsol#").replace("<", "#lt#").replace(">", "#gt#")
					.replace(":", "#colon#").replace("|", "#verbar#").replace("?", "#quest#").replace("*", "#ast#")
					.replace("\"", "#quot#").replace(" ", "#space#").toUpperCase();
		} catch (UnsupportedEncodingException e) {
			// Cannot happen, since UTF-8 is always available.
			return null;
		}
	}

	/**
	 * Gets the function group name with the prefix depending whether there is a
	 * custom namespace or not.
	 */
	public static String getFunctionGroupNameWithPrefix(String name, String prefix) {
		Matcher matcher = FUNCTION_GROUP_NAME_PATTERN.matcher(name);
		Preconditions.checkArgument(matcher.matches(), "Invalid function group name");
		return Strings.nullToEmpty(matcher.group("customNamespace")) + prefix + matcher.group("name");
	}

	/**
	 * Gets the function group name with the prefix depending whether there is a
	 * custom namespace or not.
	 */
	public static String getFunctionGroupNameWithPrefixInAdt(String name, String prefix) {
		Matcher matcher = FUNCTION_GROUP_NAME_PATTERN_IN_ADT.matcher(name);
		Preconditions.checkArgument(matcher.matches(), "Invalid function group name");
		
		String namespace = matcher.group("customNamespace");
		if (namespace != null) {
			return "%252f" + namespace + "%252f" + prefix + matcher.group("name");
		}
		
		return prefix + matcher.group("name");
	}

}
