package com.teamscale.ide.client.adt;

import java.util.Optional;
import java.util.regex.Matcher;
import java.util.regex.Pattern;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.core.resources.IProject;

/**
 * Maps a URI that matches the given pattern with the help of the given template
 * to a Teamscale URI.
 * <p>
 * It is expected that the pattern has a named group "name" and that the template 
 * has exactly one position to insert the given name into with string formatting.
 */
class SimpleAdtUriMapper implements IAdtUriMapper {

	private static final Logger LOGGER = LogManager.getLogger();
	
	private static final String GROUP = "name";

	private final Pattern pattern;
	
	private final String teamscaleUriTemplate;
	
	public SimpleAdtUriMapper(String pattern, String teamscaleUriTemplate) {
		this.pattern = Pattern.compile(pattern);
		this.teamscaleUriTemplate = teamscaleUriTemplate;
	}
	
	@Override
	public Optional<String> map(String uri, IProject project) {
		LOGGER.traceEntry(null, uri, project);
		Matcher matcher = pattern.matcher(uri);
		if (!matcher.matches()) {
			return LOGGER.traceExit(Optional.empty());
		}
		String name = AdtUriMappingUtils.convertFileNameToAbapName(matcher.group(GROUP));
		return LOGGER.traceExit(Optional.of(String.format(teamscaleUriTemplate, name)));
	}

}
