package com.teamscale.ide.commons.client;

import static java.util.stream.Collectors.joining;

import java.util.List;
import java.util.Optional;

import com.google.common.net.UrlEscapers;
import com.teamscale.ide.commons.model.IdeCommit;

/** Utility methods for computing URIs for a request to a Teamscale server */
public class Uris {

	/** Special value to indicate the HEAD of a branch. */
	private static final String HEAD_TIMESTAMP = "HEAD";

	/**
	 * Formats the given {@link IdeCommit} into the a query parameter which may be
	 * used for service calls (i.e. "t=branch:timestamp", or "t=timestamp" if no
	 * branch is specified).
	 */
	public static String asTimestampQueryParameter(IdeCommit commit) {
		String result = "";
		Optional<String> branchName = commit.getBranchName();
		if (branchName.isPresent()) {
			result += branchName.get() + ":";
		}

		long timestamp = commit.getTimestamp();
		if (timestamp == Long.MAX_VALUE) {
			result += HEAD_TIMESTAMP;
		} else {
			result += timestamp;
		}

		return result;
	}

	/**
	 * Encodes the given url path segment. Slashes will be escaped. If you want to
	 * keep them you need to split the input before and supply them one by one.
	 */
	public static String encodePathSegment(String pathSegment) {
		return UrlEscapers.urlPathSegmentEscaper().escape(pathSegment);
	}

	/**
	 * Encodes each segment using {@link #encodePathSegment(String)}, and returns
	 * the encoded segments joined with slashes.
	 */
	public static String encodePathSegments(List<String> pathSegments) {
		return pathSegments.stream().map(Uris::encodePathSegment).collect(joining("/"));
	}

	/**
	 * Encodes the given value as query parameter (includes slashes and + symbols).
	 */
	public static String encodeQueryParameter(String queryParameter) {
		return UrlEscapers.urlFormParameterEscaper().escape(queryParameter);
	}
}
