package com.teamscale.ide.commons.client.exceptions;

import static java.util.Objects.requireNonNull;

/**
 * Exception used to indicate that the server does not support a service call
 * because its version is too old.
 */
public class ApiNotSupportedException extends ApiExceptionBase {

	private static final long serialVersionUID = 1L;

	/** The lowest server version in which the service call is supported */
	private final String lowestSupportedServerVersion;

	public ApiNotSupportedException(String unsupportedEndpointUrl, String lowestSupportedServerVersion) {
		super(unsupportedEndpointUrl);

		this.lowestSupportedServerVersion = requireNonNull(lowestSupportedServerVersion);
	}

	/** Returns the URL of the endpoint that is not supported by the server. */
	public String getUnsupportedEndpoint() {
		return getMessage();
	}

	/**
	 * Returns the minimum Teamscale server version reuqired that has this API
	 * endpoint.
	 */
	public String getLowestSupportedServerVersion() {
		return lowestSupportedServerVersion;
	}

}
