package com.teamscale.ide.commons.client.exceptions;

import java.net.URI;

import com.google.common.base.Strings;
import com.teamscale.ide.commons.servers.ETeamscaleServerState;

/**
 * Exception used to indicate that an HTTP call failed with a specific error
 * code
 */
public class HttpException extends NetworkExceptionBase {

	/** The HTTP status code of the server response. */
	private final int statusCode;

	/**
	 * The status message of the server response.
	 */
	private String statusMessage = null;

	/** The body of the server response. */
	private String responseBody = null;

	public HttpException(URI serverUrl, int statusCode, ETeamscaleServerState serverState) {
		super(serverUrl, serverState);
		this.statusCode = statusCode;
	}

	public HttpException(URI requestUrl, String statusMessage, int statusCode, String responseBody) {
		super(formatMessage(requestUrl, statusMessage, statusCode, responseBody), ETeamscaleServerState.UNREACHABLE);
		this.statusCode = statusCode;
		this.statusMessage = statusMessage;
		this.responseBody = responseBody;
	}

	/** Creates a human-readable message from the given error information. */
	private static String formatMessage(URI url, String statusMessage, int statusCode, String responseBody) {
		String message = "Request to '" + url + "' was not successful: " + statusCode + " " + statusMessage;
		if (!Strings.isNullOrEmpty(responseBody)) {
			message += "\n" + responseBody;
		}

		return message;
	}

	public int getStatusCode() {
		return statusCode;
	}

	public String getStatusMessage() {
		return statusMessage;
	}

	public String getResponseBody() {
		return responseBody;
	}
}
