package com.teamscale.ide.commons.client.exceptions;

import java.net.URI;

import com.teamscale.ide.commons.servers.ETeamscaleServerState;

/**
 * Abstract superclass of all exceptions that may occur when trying to connect
 * to the Teamscale server's API.
 */
public abstract class NetworkExceptionBase extends Exception {

	private static final long serialVersionUID = 1L;

	/** The state of the server. */
	private final ETeamscaleServerState serverState;

	public NetworkExceptionBase(String message, ETeamscaleServerState serverState) {
		this(message, serverState, null);
	}

	public NetworkExceptionBase(String message, ETeamscaleServerState serverState, Throwable cause) {
		super(message, cause);
		this.serverState = serverState;
	}

	public NetworkExceptionBase(URI serverUrl, ETeamscaleServerState serverState) {
		this(serverUrl, serverState, null);
	}

	public NetworkExceptionBase(URI serverUrl, ETeamscaleServerState serverState, Throwable cause) {
		super(createMessageFromServerState(serverUrl, serverState), cause);
		this.serverState = serverState;
	}

	/**
	 * Creates a human-readable message for the given {@link ETeamscaleServerState
	 * server state}.
	 */
	protected static String createMessageFromServerState(URI serverUrl, ETeamscaleServerState serverState) {
		String reason;
		switch (serverState) {
		case UNREACHABLE:
		case NOT_AUTHENTICATED:
		case API_VERSION_MISMATCH:
		case NOT_CONFIGURED:
		case LICENSE_INVALID:
			reason = serverState.getDescription();
			break;
		default:
			throw new IllegalStateException(serverState + " is not an invalid server state");
		}
		return "Unable to establish a connection to " + serverUrl + ": " + reason;
	}

	public ETeamscaleServerState getServerState() {
		return serverState;
	}
}
