package com.teamscale.ide.commons.client.exceptions;

import java.net.URI;

import com.teamscale.ide.commons.servers.ETeamscaleServerState;
import com.teamscale.ide.commons.util.TeamscaleVersion;

/**
 * Exception used to indicate that there is a mismatch between the API version
 * of the plugin and that of a Teamscale server.
 */
public class TeamscaleApiVersionMismatchException extends NetworkExceptionBase {

	private static final long serialVersionUID = 1L;
	/** The URL of the server which has the mismatching version */
	private final URI serverUrl;

	/** The API version of the server */
	private final TeamscaleVersion serverApiVersion;

	/** The API version of the client */
	private final TeamscaleVersion clientApiVersion;

	public TeamscaleApiVersionMismatchException(URI serverUrl, TeamscaleVersion serverApiVersion,
			TeamscaleVersion clientApiVersion) {
		super(createMessage(serverApiVersion, clientApiVersion), ETeamscaleServerState.API_VERSION_MISMATCH);
		this.serverUrl = serverUrl;
		this.serverApiVersion = serverApiVersion;
		this.clientApiVersion = clientApiVersion;
	}

	private static String createMessage(TeamscaleVersion serverApiVersion, TeamscaleVersion clientApiVersion) {
		return String.format("Server version %s is not compatible with the %s service client", serverApiVersion,
				clientApiVersion);
	}

	public URI getServerUrl() {
		return serverUrl;
	}
}
