package com.teamscale.ide.commons.client.impl.v67;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.annotations.VisibleForTesting;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * DTO for {@link com.teamscale.service.repository.BranchesInfo} as returned by
 * version 6.7 of the Teamscale API.
 * <p>
 * This is just a subset of all the properties returned by the API, as for now
 * only the {@link #liveBranches} are needed.
 */
@VisibleForTesting
public class BranchesInfo67Dto {

	/**
	 * The names of all available active branches, including the default branch, but
	 * excluding deleted and anonymous branches.
	 */
	private final List<String> liveBranches;

	@JsonCreator
	public BranchesInfo67Dto(@JsonProperty("liveBranches") List<String> liveBranches) {
		this.liveBranches = liveBranches;
	}

	public List<String> getLiveBranches() {
		return liveBranches;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
