package com.teamscale.ide.commons.client.impl.v67;

import static java.util.Objects.requireNonNull;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * DTO for check descriptions as returned by version 6.7 of the Teamscale API.
 */
/* package */ class CheckDescription67Dto {

	/** The name of the JSON property name for {@link #checkName}. */
	private static final String CHECK_NAME_PROPERTY = "name";

	/** The name of the JSON property name for {@link #description}. */
	private static final String DESCRIPTION_PROPERTY = "description";

	/** The name of the check. */
	@JsonProperty(CHECK_NAME_PROPERTY)
	public final String checkName;

	/**
	 * The description of the check.
	 * <p>
	 * <strong>Note: May contain Markdown</strong>
	 */
	@JsonProperty(DESCRIPTION_PROPERTY)
	public final String description;

	@JsonCreator
	public CheckDescription67Dto(@JsonProperty(CHECK_NAME_PROPERTY) String checkName,
			@JsonProperty(DESCRIPTION_PROPERTY) String description) {
		this.checkName = requireNonNull(checkName);
		this.description = requireNonNull(description);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
