package com.teamscale.ide.commons.client.impl.v67;

import java.util.List;

import org.checkerframework.checker.nullness.qual.Nullable;
import org.conqat.engine.index.shared.TrackedFinding;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * DTO of {@link org.conqat.engine.index.shared.PreCommit3Result} as returned by
 * version 6.7 of the Teamscale API.
 */
/* package */ class PreCommit3Result67Dto {

	/**
	 * The token to poll for final results. If this is provided, you should poll for
	 * finished results later on. If this is null, the returned results are final
	 * and not further analysis will happen.
	 */
	@JsonProperty("token")
	public final @Nullable String token;

	/** Any error that occurred (may be null). */
	@JsonProperty("error")
	public final @Nullable String error;

	/**
	 * The findings. This may contain data even in case of errors. Additionally,
	 * this may be null to indicate that the findings information is not valid (i.e.
	 * during intermediate polling).
	 */
	@JsonProperty("findings")
	public final @Nullable List<TrackedFinding> findings;

	@JsonCreator
	public PreCommit3Result67Dto(@JsonProperty("token") @Nullable String token,
			@JsonProperty("error") @Nullable String error,
			@JsonProperty("findings") @Nullable List<TrackedFinding> findings) {
		this.token = token;
		this.error = error;
		this.findings = findings;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
