/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.client.impl.v67;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * DTO for {@link com.teamscale.service.ide.ProjectMapping} as returned by
 * version 6.7 of the Teamscale API.
 */
/* package */ class ProjectMapping67Dto {

	/** The full path of the file that was used for the mapping */
	public final String fullFilePath;

	/** The project id of the project that the mapping is valid for */
	public final String projectId;

	/** The local path of the mapping. */
	public final String from;

	/** The server path of the mapping. */
	public final String to;

	/** Constructor. */
	@JsonCreator
	public ProjectMapping67Dto(@JsonProperty("fullFilePath") String fullFilePath,
			@JsonProperty("projectId") String project, @JsonProperty("from") String from,
			@JsonProperty("to") String to) {
		this.fullFilePath = fullFilePath;
		this.projectId = project;
		this.from = from;
		this.to = to;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
