/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.client.impl.v67;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * Ide dto for {@link com.teamscale.commons.ServiceApiInfo}.
 */
public final class ServiceApiInfo67Dto {

	private static final String MAX_API_VERSION_PROPERTY = "maxApiVersion";

	private static final String MIN_API_VERSION_PROPERTY = "minApiVersion";

	/** The current version of the service API */
	@JsonProperty(MAX_API_VERSION_PROPERTY)
	public final TeamscaleVersion67Dto maxApiVersion;

	/** The minimum version of the service API still supported by the server */
	@JsonProperty(MIN_API_VERSION_PROPERTY)
	public final TeamscaleVersion67Dto minApiVersion;

	@JsonCreator
	public ServiceApiInfo67Dto(@JsonProperty(MAX_API_VERSION_PROPERTY) TeamscaleVersion67Dto maxApiVersion,
			@JsonProperty(MIN_API_VERSION_PROPERTY) TeamscaleVersion67Dto minApiVersion) {
		this.maxApiVersion = maxApiVersion;
		this.minApiVersion = minApiVersion;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
