/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.client.impl.v67;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * Ide dto for {@link org.conqat.lib.commons.version.Version}.
 * <p>
 * The IDE domain object for this is
 * {@link com.teamscale.ide.commons.util.TeamscaleVersion}.
 */
public final class TeamscaleVersion67Dto {

	/** The name of the JSON property name for {@link #major}. */
	private static final String MAJOR_PROPERTY = "major";

	/** The name of the JSON property name for {@link #minor}. */
	private static final String MINOR_PROPERTY = "minor";

	/** The name of the JSON property name for {@link #patch}. */
	private static final String PATCH_PROPERTY = "patch";

	/** Major version. */
	@JsonProperty(MAJOR_PROPERTY)
	public final int major;

	/** Minor version. */
	@JsonProperty(MINOR_PROPERTY)
	public final int minor;

	/** Patch level. */
	@JsonProperty(PATCH_PROPERTY)
	public final int patch;

	/**
	 * Create a new version.
	 *
	 * @param major
	 *            major version number.
	 * @param minor
	 *            minor version number.
	 * @param patch
	 *            patch version number.
	 * @throws IllegalArgumentException
	 *             if one of the version numbers is less than 0.
	 */
	@JsonCreator
	public TeamscaleVersion67Dto(@JsonProperty(MAJOR_PROPERTY) int major, @JsonProperty(MINOR_PROPERTY) int minor,
			@JsonProperty(PATCH_PROPERTY) int patch) {
		if (major < 0 || minor < 0 || patch < 0) {
			throw new IllegalArgumentException("Versions may not be less than 0.");
		}
		this.major = major;
		this.minor = minor;
		this.patch = patch;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}