package com.teamscale.ide.commons.client.impl.v71;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.google.common.annotations.VisibleForTesting;
import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * DTO for {@link org.conqat.engine.index.shared.ProjectInfo} as returned by
 * version 7.1 of the Teamscale API.
 */
@VisibleForTesting
public class ProjectInfo71Dto {

	/** The name of the JSON property name for {@link #name}. */
	private static final String NAME_PROPERTY = "name";

	/** The name of the JSON property name for {@link #publicIds}. */
	private static final String PUBLIC_IDS_PROPERTY = "publicIds";

	/** The project name. */
	@JsonProperty(NAME_PROPERTY)
	public final String name;

	/**
	 * The public IDs of this project. Size of this list is guaranteed to be >= 1,
	 * and the primary public ID of the project is always the first element of the
	 * list.
	 */
	@JsonProperty(PUBLIC_IDS_PROPERTY)
	public final List<String> publicIds;

	@JsonCreator
	public ProjectInfo71Dto(@JsonProperty(NAME_PROPERTY) String name,
			@JsonProperty(PUBLIC_IDS_PROPERTY) List<String> publicIds) {
		this.name = name;
		this.publicIds = publicIds;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
