/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.client.tasks;

import com.teamscale.ide.commons.client.services.ITeamscaleConnectorService;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.TaskBase;
import com.teamscale.ide.commons.servers.NamedServerDetails;

/**
 * Updates the server state for a given server.
 */
public class ServerStateUpdateTask extends TaskBase {

	/** The server for which the state should be updated. */
	private final NamedServerDetails server;

	private final ITeamscaleConnectorService connectorService;

	public ServerStateUpdateTask(IServiceRegistry serviceRegistry, NamedServerDetails server) {
		super(server, "Querying server state");
		this.server = server;

		connectorService = serviceRegistry.getService(ITeamscaleConnectorService.class);
	}

	@Override
	protected void run() {
		connectorService.getAndBroadcastServerState(server);
	}
}
