/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.findings;

import java.net.URI;

import com.teamscale.ide.commons.client.Uris;
import com.teamscale.ide.commons.model.IdeCommit;
import com.teamscale.ide.commons.model.RemoteResourceReference;

/**
 * Utility methods for computing URIs for findings on a Teamscale server.
 */
public class FindingUris {

	/**
	 * @return an {@link URI} reference to the Findings Detail view of the given
	 *         finding.
	 */
	public static URI createUri(Finding finding) {
		RemoteResourceReference remoteResource = finding.getRemoteResource();
		URI serverUrl = remoteResource.getServerUrl();
		StringBuilder uri = new StringBuilder(serverUrl.toString());
		if (uri.charAt(uri.length() - 1) != '/') {
			uri.append('/');
		}
		uri.append("findings.html").append('#').append("details");
		uri.append('/').append(Uris.encodePathSegment(remoteResource.getTeamscaleProject()));
		uri.append('?').append("id").append('=').append(Uris.encodeQueryParameter(finding.getId()));
		if (remoteResource.getBranch().isPresent()) {
			String commitQueryParameter = "t=" + Uris.encodeQueryParameter(
					Uris.asTimestampQueryParameter(IdeCommit.head(remoteResource.getBranch().get())));
			uri.append('&').append(commitQueryParameter);
		}

		return URI.create(uri.toString());
	}
}
