package com.teamscale.ide.commons.findings;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;

/** Represents a check description. */
public final class IdeCheckDescription {

	/** The name of the check which created the finding. */
	private final String checkName;

	/**
	 * The description of the check.
	 * <p>
	 * <strong>Note: May contain Markdown</strong>
	 */
	private final String description;

	/** The {@link URI} of the server the description was fetched from. */
	private final URI serverUri;

	public IdeCheckDescription(String checkName, String description, URI serverUri) {
		this.checkName = requireNonNull(checkName);
		this.description = requireNonNull(description);
		this.serverUri = requireNonNull(serverUri);
	}

	/** @see #getId(URI, String) */
	public String getId() {
		return getId(serverUri, checkName);
	}

	/** @see #getId(URI, String) */
	public static String getId(URI serverUri, Finding finding) {
		return getId(serverUri, finding.getTypeId());
	}

	/**
	 * Returns the ID that can be used to uniquely identify a
	 * {@link IdeCheckDescription}.
	 */
	private static String getId(URI serverUri, String checkName) {
		return serverUri + "#" + checkName;
	}

	/** @see #checkName */
	public String getCheckName() {
		return checkName;
	}

	/** @see #description */
	public String getDescription() {
		return description;
	}

	/** @see #serverUri */
	public URI getServerUri() {
		return serverUri;
	}

	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		}
		if (other == null) {
			return false;
		}
		if (getClass() != other.getClass()) {
			return false;
		}
		IdeCheckDescription that = (IdeCheckDescription) other;
		return Objects.equals(checkName, that.checkName) //
				&& Objects.equals(description, that.description) //
				&& Objects.equals(serverUri, that.serverUri);
	}

	@Override
	public int hashCode() {
		return Objects.hash(checkName, description, serverUri);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
