package com.teamscale.ide.commons.findings.services;

import java.net.URI;
import java.util.Optional;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.findings.IdeCheckDescription;
import com.teamscale.ide.commons.plugin.IPluginService;
import com.teamscale.ide.commons.util.IEventListenable;

/** Keeps a cache of check descriptions. */
public interface ICheckDescriptionStoreService extends IPluginService, IEventListenable<ICheckDescriptionListener> {

	/**
	 * Caches the check description and broadcasts it to all
	 * {@link ICheckDescriptionListener}s.
	 *
	 * @param serverUri
	 *            the URL of the server the description was fetched from
	 * @param finding
	 *            the {@link Finding} the description belongs to
	 * @param description
	 *            the description of the check
	 */
	void setCheckDescription(URI serverUri, Finding finding, IdeCheckDescription description);

	/**
	 * @param serverUri
	 *            the URL of the server the description might have been fetched from
	 * @param finding
	 *            the {@link Finding} for which the cached description should be
	 *            retrieved
	 * @return the check description for the given {@link URI server} and
	 *         {@link Finding} if it has been cached already, or
	 *         {@link Optional#empty()} otherwise.
	 */
	Optional<IdeCheckDescription> getCheckDescription(URI serverUri, Finding finding);
}
