package com.teamscale.ide.commons.findings.services.impl;

import java.net.URI;
import java.util.Optional;

import com.google.common.cache.Cache;
import com.google.common.cache.CacheBuilder;
import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.findings.IdeCheckDescription;
import com.teamscale.ide.commons.findings.services.ICheckDescriptionListener;
import com.teamscale.ide.commons.findings.services.ICheckDescriptionStoreService;
import com.teamscale.ide.commons.util.EventListenableBase;

/**
 * Caches requested check descriptions. Also broadcasts new check descriptions
 * to registered {@link ICheckDescriptionListener}s.
 */
public class CheckDescriptionStoreService extends EventListenableBase<ICheckDescriptionListener>
		implements ICheckDescriptionStoreService {

	/** The maximum number of check descriptions that should be cached. */
	private static final int MAX_CACHED_CHECK_DESCRIPTIONS = 30;

	/**
	 * In-memory check descriptions cache that stores at most
	 * {@value MAX_CACHED_CHECK_DESCRIPTIONS} descriptions.
	 */
	private final Cache<String, IdeCheckDescription> cache = CacheBuilder.newBuilder() //
			.concurrencyLevel(1) //
			.maximumSize(MAX_CACHED_CHECK_DESCRIPTIONS) //
			.build();

	@Override
	public void setCheckDescription(URI serverUri, Finding finding, IdeCheckDescription description) {
		cache.put(description.getId(), description);

		notifyListeners(listener -> listener.onCheckDescriptionLoaded(serverUri, finding, description));
	}

	@Override
	public Optional<IdeCheckDescription> getCheckDescription(URI serverUri, Finding finding) {
		return Optional.ofNullable(cache.getIfPresent(IdeCheckDescription.getId(serverUri, finding)));
	}
}
