/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.findings.tasks;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import com.teamscale.ide.commons.client.exceptions.NetworkExceptionBase;
import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.model.RemoteResourceReference;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.servers.NamedServerDetails;

/** Task for flagging a {@link Finding} as tolerated. */
public class FlagFindingAsToleratedTask extends BlacklistFindingTaskBase {
	// Class argument necessary due to
	// <https://youtrack.jetbrains.com/issue/IDEA-220300>.
	private static final Logger LOGGER = LogManager.getLogger(FlagFindingAsToleratedTask.class);

	public FlagFindingAsToleratedTask(IServiceRegistry serviceRegistry, Finding finding, String rationale) {
		super(serviceRegistry, finding, rationale, "Flagging finding as tolerated");
	}

	@Override
	protected boolean performBlacklistingService(NamedServerDetails serverDetails,
			RemoteResourceReference remoteResource, String baseBranch) throws NetworkExceptionBase {
		LOGGER.traceEntry(null, serverDetails, remoteResource, baseBranch);

		boolean wasSuccessful = connectorService.flagFindingAsTolerated(serverDetails,
				remoteResource.getTeamscaleProject(), finding, System.currentTimeMillis(), baseBranch, rationale);

		return LOGGER.traceExit(wasSuccessful);
	}
}
