/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.findings.tasks;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Collection;
import java.util.Collections;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.findings.FindingUris;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.tasks.OpenInBrowserTaskBase;

/**
 * Task which opens the given resource in the system's default browser.
 */
public class OpenFindingInBrowserTask extends OpenInBrowserTaskBase {

	/** The finding which should be shown in the browser. */
	private final Finding finding;

	public OpenFindingInBrowserTask(IServiceRegistry serviceRegistry, Finding finding) {
		super(serviceRegistry, "Opening finding in browser");

		this.finding = requireNonNull(finding);
	}

	@Override
	protected Collection<URI> createUri() {
		return Collections.singleton(FindingUris.createUri(finding));
	}
}
