/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.logging;

import org.apache.logging.log4j.core.Appender;
import org.apache.logging.log4j.core.appender.AbstractAppender;
import org.apache.logging.log4j.core.config.plugins.PluginElement;
import org.apache.logging.log4j.core.config.plugins.validation.constraints.Required;
import org.apache.logging.log4j.core.util.Builder;

/**
 * Base class for {@link Builder}s of Log4J {@link Appender}s, adding
 * {@code <Rule>} configuration elements to the common elements like name and
 * layout.
 */
public abstract class AppenderBuilderBase<T extends Appender> extends AbstractAppender.Builder<AppenderBuilderBase<T>>
		implements Builder<T> {

	/**
	 * The {@linkplain Rule rules} that govern how the built appender maps log
	 * events to IDE-specific keys.
	 */
	@Required
	@PluginElement("Rules")
	private Rule[] rules;

	/** @see #rules */
	public Rule[] getRules() {
		return rules;
	}

	/** @see #rules */
	public AppenderBuilderBase<T> setRules(Rule... rules) {
		this.rules = rules;
		return asBuilder();
	}
}
