/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.mappings;

import java.util.Optional;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;

import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.vcs.CheckoutUtils;
import com.teamscale.ide.commons.vcs.services.ICheckoutFactory;

/**
 * Utility class to make it easier to perform common resource mapping tasks.
 */
public class MappingUtils {

	// Class argument necessary due to
	// <https://youtrack.jetbrains.com/issue/IDEA-220300>.
	private static final Logger LOGGER = LogManager.getLogger(MappingUtils.class);

	/**
	 * Returns the branch for the given {@link ResourceReference}, taking any
	 * possible {@linkplain ResourceMappingResult#getBranchOverride() branch
	 * overrides} into account.
	 */
	public static Optional<String> getBranch(ICheckoutFactory checkoutFactory, ResourceReference resource,
			ResourceMappingResult mappingResult) {
		Optional<String> overriddenBranch = mappingResult.getBranchOverride();
		if (overriddenBranch.isPresent()) {
			LOGGER.debug("Treating {} to be on branch '{}' (override applied).", () -> resource, overriddenBranch::get);
			return overriddenBranch;
		}

		Optional<String> checkedOutBranch = CheckoutUtils.getCheckedOutBranch(checkoutFactory, resource);
		if (checkedOutBranch.isPresent()) {
			LOGGER.debug("Treating {} to be on branch {} (checked out).", () -> resource, checkedOutBranch::get);
			return checkedOutBranch;
		}

		LOGGER.debug("Treating {} to be on no branch.", resource);
		return Optional.empty();
	}
}
