/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.mappings.tasks;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Collection;
import java.util.Collections;

import com.teamscale.ide.commons.mappings.MappingUris;
import com.teamscale.ide.commons.model.RemoteResourceReference;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.tasks.OpenInBrowserTaskBase;

/**
 * Task which opens the given remote resource in the system's default browser.
 */
public class OpenRemoteResourceInBrowserTask extends OpenInBrowserTaskBase {

	/** The remote resource which should be shown in the browser. */
	private final RemoteResourceReference remoteResource;

	public OpenRemoteResourceInBrowserTask(IServiceRegistry serviceRegistry, RemoteResourceReference remoteResource) {
		super(serviceRegistry, "Opening resource in browser");

		this.remoteResource = requireNonNull(remoteResource);
	}

	@Override
	protected Collection<URI> createUri() {
		return Collections.singleton(MappingUris.createUri(remoteResource));
	}
}
