/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.model;

import java.util.Objects;
import java.util.Optional;

import org.checkerframework.checker.nullness.qual.Nullable;

import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * A {@link VcsResourceReference} points to a file or folder on a particular
 * branch in a version-control system (VCS). The file or folder need not exist.
 */
public class VcsResourceReference {

	/** The referenced resource. */
	private final ResourceReference resource;

	/** The branch, if any, the referenced resource is on. */
	private final @Nullable String branch;

	public VcsResourceReference(ResourceReference resource, @Nullable String branch) {
		this.resource = Objects.requireNonNull(resource);
		this.branch = branch;
	}

	/** @see #resource */
	public ResourceReference getResource() {
		return resource;
	}

	/** @see #branch */
	public Optional<String> getBranch() {
		return Optional.ofNullable(branch);
	}

	@Override
	public int hashCode() {
		return Objects.hash(resource, branch);
	}

	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		}
		if (other == null) {
			return false;
		}
		if (getClass() != other.getClass()) {
			return false;
		}
		final VcsResourceReference that = (VcsResourceReference) other;
		return Objects.equals(this.resource, that.resource) && Objects.equals(this.branch, that.branch);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
