/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification;

/**
 * Whether the cause of the notification was a direct, Teamscale-specific action
 * by the user (e.g., clicking "Refresh Findings") or whether it was caused
 * indirectly by an action that merely has some Teamscale-related side effect
 * (e.g., opening a file, which implicitly causes findings to be fetched).
 */
public enum ENotificationCause {

	/**
	 * There was a direct, Teamscale-specific action by the user (e.g., clicking
	 * "Upload for Pre-Commit Analysis") that caused the notification.
	 */
	DIRECT,

	/**
	 * There was no direct action by the user that caused the notification, but
	 * merely an indirect one that has some Teamscale-related side effect (e.g.,
	 * opening a file, which indirectly causes findings to be fetched).
	 */
	INDIRECT
}
