/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that a specific action is not supported by the Teamscale server
 */
public final class ApiNotSupportedNotification implements INotification<ApiNotSupportedNotification> {

	private final URI serverUrl;
	private final String lowestSupportedServerVersion;
	private final String message;

	public ApiNotSupportedNotification(URI serverUrl, String lowestSupportedServerVersion, String message) {
		this.serverUrl = requireNonNull(serverUrl);
		this.lowestSupportedServerVersion = requireNonNull(lowestSupportedServerVersion);
		this.message = requireNonNull(message);
	}

	@Override
	public boolean isSubsumedBy(ApiNotSupportedNotification that) {
		return Objects.equals(serverUrl, that.serverUrl)
				&& Objects.equals(lowestSupportedServerVersion, that.getLowestSupportedServerVersion())
				&& Objects.equals(message, that.getMessage());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportApiNotSupported(this);
	}

	public String getLowestSupportedServerVersion() {
		return lowestSupportedServerVersion;
	}

	public String getMessage() {
		return message;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
