/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notification that the CheckDescription of the given id can not be found.
 */
public final class CheckDescriptionNotFoundNotification implements INotification<CheckDescriptionNotFoundNotification> {

	private final String checkId;

	public CheckDescriptionNotFoundNotification(String checkId) {
		this.checkId = requireNonNull(checkId);
	}

	@Override
	public boolean isSubsumedBy(CheckDescriptionNotFoundNotification that) {
		return Objects.equals(checkId, that.getCheckId());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportCheckDescriptionNotFound(this);
	}

	public String getCheckId() {
		return checkId;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
