/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.notification.INotification;
import com.teamscale.ide.commons.servers.ETeamscaleServerState;

/**
 * Notifies that there was a connection error with a Teamscale server
 */
public final class ConnectionErrorNotification implements INotification<ConnectionErrorNotification> {

	private final URI serverUrl;
	private final ETeamscaleServerState serverState;

	public ConnectionErrorNotification(URI serverUrl, ETeamscaleServerState serverState) {
		this.serverUrl = requireNonNull(serverUrl);
		this.serverState = serverState;
	}

	@Override
	public boolean isSubsumedBy(ConnectionErrorNotification that) {
		return Objects.equals(serverUrl, that.serverUrl) && serverState == that.serverState;
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportConnectionError(this);
	}

	public String getMessage() {
		return String.format("%s: %s", serverUrl, serverState.getDescription());
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
