package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.client.services.impl.TeamscaleConnectorService;
import com.teamscale.ide.commons.notification.INotification;
import com.teamscale.ide.commons.util.TeamscaleVersion;

/**
 * Notifies the user that the server has a higher version than the plugin, and
 * it is therefore recommended to update the plugin
 *
 * @see TeamscaleConnectorService#shouldRecommendPluginUpdate(TeamscaleVersion,
 *      TeamscaleVersion)
 */
public class HigherServerVersionWarningNotification implements INotification<HigherServerVersionWarningNotification> {

	/** The URL of the server */
	private final URI serverUrl;

	/** The Teamscale version of the server */
	private final TeamscaleVersion serverVersion;

	/** The version of the plugin */
	private final TeamscaleVersion pluginVersion;

	public HigherServerVersionWarningNotification(URI serverUrl, TeamscaleVersion serverVersion,
			TeamscaleVersion pluginVersion) {
		this.serverUrl = requireNonNull(serverUrl);
		this.serverVersion = requireNonNull(serverVersion);
		this.pluginVersion = requireNonNull(pluginVersion);
	}

	@Override
	public boolean isSubsumedBy(HigherServerVersionWarningNotification that) {
		return Objects.equals(serverUrl, that.serverUrl);
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportHigherServerVersionWarning(this);
	}

	public URI getServerUrl() {
		return serverUrl;
	}

	public TeamscaleVersion getServerVersion() {
		return serverVersion;
	}

	public TeamscaleVersion getPluginVersion() {
		return pluginVersion;
	}
}
