/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import com.teamscale.ide.commons.notification.ENotificationCause;
import com.teamscale.ide.commons.notification.INotification;
import com.teamscale.ide.commons.notification.impl.legacy.ILegacyNotificationVisitor;
import com.teamscale.ide.commons.notification.services.INotificationService;

/**
 * Manages specific notifications.
 * <p>
 * This should only be used by the implementations of
 * {@link INotificationService} and the implementations of
 * {@link INotification}. Client code should use
 * {@link INotificationService#reportNotification(ENotificationCause, INotification)}
 */
public interface INotificationVisitor extends ILegacyNotificationVisitor {

	/** @see PreCommitErrorNotification */
	void reportPreCommitError(PreCommitErrorNotification notification);

	/** @see ServerUrlNotFoundNotification */
	void reportServerUrlNotFound(ServerUrlNotFoundNotification notification);

	/** @see ConnectionErrorNotification */
	void reportConnectionError(ConnectionErrorNotification notification);

	/** @see ApiNotSupportedNotification */
	void reportApiNotSupported(ApiNotSupportedNotification notification);

	/** @see HigherServerVersionWarningNotification */
	void reportHigherServerVersionWarning(HigherServerVersionWarningNotification notification);

	/** @see ProjectNotFoundNotification */
	void reportProjectNotFound(ProjectNotFoundNotification notification);

	/** @see TeamscaleBranchNotFoundNotification */
	void reportTeamscaleBranchNotFound(TeamscaleBranchNotFoundNotification notification);

	/** @see ResourceOutsideMappingRootNotification */
	void reportResourceOutsideMappingRoot(ResourceOutsideMappingRootNotification notification);

	/** @see ServerUnknownNotification */
	void reportServerUnknown(ServerUnknownNotification notification);

	/** @see NoMappingFoundNotification */
	void reportNoMappingFound(NoMappingFoundNotification notification);

	/** @see TomlConfigInvalidNotification */
	void reportTomlConfigInvalid(TomlConfigInvalidNotification notification);

	/** @see FailedOpenUrisNotification */
	void reportFailedOpenUris(FailedOpenUrisNotification notification);

	/** @see CheckDescriptionNotFoundNotification */
	void reportCheckDescriptionNotFound(CheckDescriptionNotFoundNotification notification);

	/** @see SapTeamscaleSyncTimeoutNotification */
	void reportSapTeamscaleSyncTimeout(SapTeamscaleSyncTimeoutNotification notification);
}
