/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that a project does not exist on the corresponding Teamscale server
 */
public final class ProjectNotFoundNotification implements INotification<ProjectNotFoundNotification> {

	private final URI serverUrl;
	private final String projectId;

	public ProjectNotFoundNotification(URI serverUrl, String projectId) {
		this.serverUrl = requireNonNull(serverUrl);
		this.projectId = requireNonNull(projectId);
	}

	@Override
	public boolean isSubsumedBy(ProjectNotFoundNotification that) {
		return Objects.equals(serverUrl, that.getServerUrl()) && Objects.equals(projectId, that.getProjectId());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportProjectNotFound(this);
	}

	public URI getServerUrl() {
		return serverUrl;
	}

	public String getProjectId() {
		return projectId;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
