/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.mappings.MappingProblem;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that a specific {@link ResourceReference resource} is outside the
 * mapping root
 *
 * @see MappingProblem.EType#RESOURCE_OUTSIDE_MAPPING_ROOT
 */
public final class ResourceOutsideMappingRootNotification
		implements INotification<ResourceOutsideMappingRootNotification> {

	private final ResourceReference resource;

	public ResourceOutsideMappingRootNotification(ResourceReference resource) {
		this.resource = requireNonNull(resource);
	}

	@Override
	public boolean isSubsumedBy(ResourceOutsideMappingRootNotification that) {
		return Objects.equals(resource, that.getResource());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportResourceOutsideMappingRoot(this);
	}

	public ResourceReference getResource() {
		return resource;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
