/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.util.Objects;

import org.checkerframework.checker.nullness.qual.Nullable;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.mappings.MappingProblem;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that a for a specific {@link ResourceReference mappingRoot} the
 * corresponding Teamscale server is unknown.
 *
 * @see MappingProblem.EType#TEAMSCALE_SERVER_UNKNOWN
 */
public final class ServerUnknownNotification implements INotification<ServerUnknownNotification> {

	@Nullable
	private final ResourceReference mappingRoot;
	private final String serverUrl;

	public ServerUnknownNotification(@Nullable ResourceReference mappingRoot, String serverUrl) {
		this.mappingRoot = mappingRoot;
		this.serverUrl = requireNonNull(serverUrl);
	}

	@Override
	public boolean isSubsumedBy(ServerUnknownNotification that) {
		return Objects.equals(mappingRoot, that.getMappingRoot()) && Objects.equals(serverUrl, that.getServerUrl());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportServerUnknown(this);
	}

	public @Nullable ResourceReference getMappingRoot() {
		return mappingRoot;
	}

	public String getServerUrl() {
		return serverUrl;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
