/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that for a given server and project the specific branch could not be
 * found
 */
public final class TeamscaleBranchNotFoundNotification implements INotification<TeamscaleBranchNotFoundNotification> {

	private final URI serverUrl;
	private final String projectId;
	private final String branch;

	public TeamscaleBranchNotFoundNotification(URI serverUrl, String projectId, String branch) {
		this.serverUrl = requireNonNull(serverUrl);
		this.projectId = requireNonNull(projectId);
		this.branch = branch; // The branch can be null. This indicates the use of the default branch of the
								// server.
	}

	@Override
	public boolean isSubsumedBy(TeamscaleBranchNotFoundNotification that) {
		return Objects.equals(serverUrl, that.getServerUrl()) && Objects.equals(projectId, that.getProjectId())
				&& Objects.equals(branch, that.getBranch());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportTeamscaleBranchNotFound(this);
	}

	public URI getServerUrl() {
		return serverUrl;
	}

	public String getProjectId() {
		return projectId;
	}

	public String getBranch() {
		return branch;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
