/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.impl;

import static java.util.Objects.requireNonNull;

import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.mappings.MappingProblem;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.notification.INotification;

/**
 * Notifies that a specific {@link ResourceReference tomlFile} is invalid.
 *
 * @see MappingProblem.EType#TOML_CONFIG_INVALID
 */
public final class TomlConfigInvalidNotification implements INotification<TomlConfigInvalidNotification> {

	private final ResourceReference tomlFileReference;
	private final String message;

	public TomlConfigInvalidNotification(ResourceReference tomlFileReference, String message) {
		this.tomlFileReference = requireNonNull(tomlFileReference);
		this.message = requireNonNull(message);
	}

	@Override
	public boolean isSubsumedBy(TomlConfigInvalidNotification that) {
		return Objects.equals(tomlFileReference, that.getTomlFileReference())
				&& Objects.equals(message, that.getMessage());
	}

	@Override
	public void accept(INotificationVisitor visitor) {
		visitor.reportTomlConfigInvalid(this);
	}

	public ResourceReference getTomlFileReference() {
		return tomlFileReference;
	}

	public String getMessage() {
		return message;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
