/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.notification.services.impl;

import com.teamscale.ide.commons.notification.ENotificationCause;
import com.teamscale.ide.commons.notification.INotification;
import com.teamscale.ide.commons.notification.impl.INotificationVisitor;
import com.teamscale.ide.commons.notification.services.INotificationMemory;
import com.teamscale.ide.commons.notification.services.INotificationService;

/**
 * Base notification service for all IDE plugins.
 * <p>
 * It implements the {@link INotificationMemory} logic.
 */
public abstract class NotificationServiceBase implements INotificationVisitor, INotificationService {

	private final INotificationMemory notificationMemory;

	protected NotificationServiceBase(INotificationMemory notificationMemory) {
		this.notificationMemory = notificationMemory;
	}

	@Override
	public void reportNotification(ENotificationCause cause, INotification<?> notification) {
		if (notificationMemory.shouldShow(cause, notification)) {
			notification.accept(this);
		}
	}
}
