
/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.plugin;

/**
 * A marker interface for plug-in services meant to be registered with a
 * {@link IServiceRegistry}.
 * <p>
 * A plug-in service typically provides a <em>coherent set of functionality</em>
 * that is independent of other plug-in services. In many cases, this
 * functionality will be implemented in an IDE-specific way. However, there may
 * also exist generic implementations. These generic implementations can be used
 * if no IDE-specific implementation exists (yet). For example, a service might
 * offer the necessary functionality to open a web page in a browser. An
 * IDE-specific implementation thereof could do this in a browser embedded into
 * the IDE, whereas a generic implementation would need to resort to the
 * desktop's default browser. In some cases, though, a plug-in service is
 * fundamentally generic, i.e., its implementation can be the same across all
 * IDE plug-ins. This is totally acceptable. Even then, implementing such
 * functionality as a plug-in service (as compared to a collection of
 * {@code static} utility methods) gives a particular IDE plug-in the
 * flexibility to add IDE-specific behavior if needed, e.g., by applying the
 * Decorator design pattern and wrapping the generic plug-in service.
 * <p>
 * What exactly constitutes a <em>coherent set of functionality</em> may not
 * always be easy to judge. However, the following guidelines can help when
 * designing a new plug-in service:
 * <ul>
 * <li>The service's methods should be independently useful, i.e., they should
 * not only ever be called in the same sequence. (Otherwise, the methods can be
 * subsumed by a single, more coarse-grained method.)</li>
 * <li>The methods should either all be implemented in an IDE-specific way or
 * all be generic. (Otherwise, the mixture of IDE-specific and generic methods
 * can be split into two services.)</li>
 * <li>The methods should neither directly (as a parameter) or indirectly (as a
 * field of the plug-in service) reference another plug-in service.
 * (Interactions between multiple plug-in services should be implemented as
 * {@linkplain com.teamscale.ide.commons.plugin.services.TaskBase tasks}.)</li>
 * </ul>
 */
public interface IPluginService {

	// This is a marker interface that needs to be extended by another interface.
}
