/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.plugin.services;

/**
 * A signal to the {@link ITaskExecutor} how to deal with a
 * {@linkplain TaskBase#run() running} {@linkplain TaskBase task} when the
 * execution of another tasks with the same combination of
 * {@linkplain Object#getClass() implementation class} and
 * {@linkplain TaskBase#getToken() token} is requested.
 */
public enum ETaskInterruptionMode {

	/**
	 * The currently running task should be canceled, and the interrupting task
	 * should be run instead.
	 */
	CANCEL,

	/**
	 * The currently running task should finish its execution, and the interrupting
	 * task should be queued and wait to be run, replacing any task already waiting.
	 * In other words, there is <b>at most one task</b> waiting to be run.
	 */
	WAIT
}
