/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.plugin.services;

/**
 * The desired visibility of a {@linkplain TaskBase task} in the UI.
 * <p>
 * This is only a hint to the {@link ITaskExecutor}; an IDE-specific
 * implementation may not support all possible visibility values.
 */
public enum ETaskVisibility {

	/**
	 * The task's execution should be completely invisible to the user. This
	 * visibility value should be used for extremely short-running or low-level
	 * tasks, which the user may not even be aware of.
	 */
	INVISIBLE,

	/**
	 * The task's execution should be presented to the user in an unobtrusive
	 * fashion. This visibility value is the common case and suitable for both short
	 * and long-running tasks.
	 */
	UNOBTRUSIVE,

	/**
	 * The task's execution should be made obvious to the user. This visibility
	 * value should be used for long-running tasks where visible progress reporting
	 * is desired and which the user may actively want to cancel.
	 */
	OBVIOUS
}
