/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.plugin.services;

import java.util.Optional;

import com.teamscale.ide.commons.model.IIDEProject;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.plugin.IPluginService;

/**
 * A {@linkplain IPluginService service} that provides access to the content of
 * local files backing the local resource references.
 */
public interface IResourceResolutionService extends IPluginService {

	/** Signifies that the size of a resource is unknown. */
	static long UNKNOWN_SIZE = -1;

	/**
	 * @return the project the given resource reference is contained in, if any.
	 *
	 * @deprecated Should not be necessary once the IDE in question has made the
	 *             switch to {@code .teamscale.toml}-based configuration.
	 */
	@Deprecated
	Optional<IIDEProject> getContainingProject(ResourceReference reference);

	/**
	 * @return the textual contents of the physical resource referenced by the given
	 *         resource reference, if any.
	 */
	Optional<String> readContents(ResourceReference resource);

	/**
	 * @return the size of the local resource, in bytes, or {@link #UNKNOWN_SIZE} if
	 *         the local resource does not exist.
	 */
	long determineSize(ResourceReference reference);
}
