/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.precommit;

import java.util.Locale;

import com.teamscale.commons.service.client.ServerDetails;

import com.teamscale.ide.commons.model.IdeCommit;

/**
 * Defines constants used for the pre-commit analysis.
 */
public class PreCommitUtils {

	/** Prefix that identifies pre-commit branches. */
	private static final String PRE_COMMIT_BRANCH_PREFIX = "__precommit__";

	/** Infix used to encode a pre-commit branch based on a specific branch. */
	private static final String PRECOMMIT_BRANCH_INFIX = "__branch__";

	/**
	 * @return whether the given branch name belongs to a special pre-commit branch
	 */
	public static boolean isPreCommitBranch(String branchName) {
		if (branchName == null) {
			return false;
		}
		return branchName.startsWith(PRE_COMMIT_BRANCH_PREFIX);
	}

	/** @return whether the given commit is on a special pre-commit branch */
	public static boolean isPreCommitBranch(IdeCommit commit) {
		return isPreCommitBranch(commit.getBranchName().orElse(null));
	}

	/** @return the complete pre-commit 3 branch name for the given parameters. */
	public static String getPreCommit3BranchName(ServerDetails serverDetails, String baseBranch) {
		String userName = serverDetails.getUsername();
		// Server-side, the user name is always lower-case
		return getPreCommit3BranchName(userName, baseBranch);
	}

	/** @return the complete pre-commit 3 branch name for the given parameters. */
	public static String getPreCommit3BranchName(String userName, String baseBranch) {
		// Server-side, the user name is always lower-case
		return PRE_COMMIT_BRANCH_PREFIX + userName.toLowerCase(Locale.ROOT) + PRECOMMIT_BRANCH_INFIX + baseBranch;
	}
}
