/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.servers;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * Authentication information to log into a specific Teamscale server.
 */
public final class AuthenticationInfo {

	private final String username;
	private final String password;
	private final boolean trustAllCertificates;

	public AuthenticationInfo(String username, String password, boolean trustAllCertificates) {
		this.username = Objects.requireNonNull(username);
		this.password = Objects.requireNonNull(password);
		this.trustAllCertificates = trustAllCertificates;
	}

	public String getUsername() {
		return username;
	}

	public String getPassword() {
		return password;
	}

	public boolean isTrustAllCertificates() {
		return trustAllCertificates;
	}

	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		}
		if (other == null || getClass() != other.getClass()) {
			return false;
		}
		AuthenticationInfo that = (AuthenticationInfo) other;
		return Objects.equals(username, that.username) && Objects.equals(password, that.password)
				&& trustAllCertificates == that.trustAllCertificates;
	}

	@Override
	public int hashCode() {
		return Objects.hash(username, password, trustAllCertificates);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}

	/**
	 * Transforms the url into a {@link NamedServerDetails}
	 */
	public NamedServerDetails asNamedServerDetails(URI url) {
		return new NamedServerDetails(url.toString(), url.toString(), getUsername(), getPassword(),
				isTrustAllCertificates());
	}
}
