/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.servers;

/**
 * All possible server states of IDE plugins with respect to a Teamscale server.
 */
public enum ETeamscaleServerState {

	/** Server is reachable. */
	REACHABLE("Teamscale server is reachable"),

	/** Server is unreachable. */
	UNREACHABLE("Teamscale server is not reachable"),

	/**
	 * Server is reachable but credentials are incorrect, thus authentication
	 * failed.
	 */
	NOT_AUTHENTICATED("Authentication failed"),

	/**
	 * Indicates that there is a mismatch between the API version of the plugin and
	 * that of a Teamscale server.
	 */
	API_VERSION_MISMATCH("Plugin API mismatches Teamscale server API"),

	/** Project configuration is incomplete. */
	NOT_CONFIGURED("Teamscale is not configured correctly for this project"),

	/** Teamscale license has expired. */
	LICENSE_INVALID("Teamscale server is reachable but the license is invalid");

	/** Description for this state. */
	private final String description;

	/**
	 * Create a new state with the given description.
	 *
	 * @param description
	 *            The description for the state
	 */
	ETeamscaleServerState(String description) {
		this.description = description;
	}

	/** @see #description */
	public String getDescription() {
		return description;
	}
}
