/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.servers.services;

import java.util.Optional;

import com.teamscale.ide.commons.plugin.IPluginService;
import com.teamscale.ide.commons.servers.ETeamscaleServerState;
import com.teamscale.ide.commons.servers.NamedServerDetails;
import com.teamscale.ide.commons.util.IEventListenable;

/**
 * Manages server states and broadcasts changes to registered
 * {@link IServerStateChangeListener})s. States should only be updated from the
 * {@link com.teamscale.ide.commons.client.services.ITeamscaleConnectorService}
 * to prevent duplicate updates.
 */
public interface IServerStateBroadcastService extends IEventListenable<IServerStateChangeListener>, IPluginService {
	/**
	 * Returns an {@link Optional} containing the currently stored state of the
	 * given server. Returns {@link Optional#empty()} if no state has been stored
	 * for this server yet.
	 */
	Optional<ETeamscaleServerState> getServerState(NamedServerDetails serverDetails);

	/**
	 * Updates the state of a server and broadcasts the state to the set of
	 * registered listeners. The new state must not be <code>null</code>.
	 */
	void updateServerState(NamedServerDetails serverDetails, ETeamscaleServerState state);
}
