/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.servers.services.impl;

import java.util.Objects;
import java.util.Optional;
import java.util.concurrent.ConcurrentHashMap;
import java.util.concurrent.ConcurrentMap;

import com.teamscale.ide.commons.servers.ETeamscaleServerState;
import com.teamscale.ide.commons.servers.NamedServerDetails;
import com.teamscale.ide.commons.servers.services.IServerStateBroadcastService;
import com.teamscale.ide.commons.servers.services.IServerStateChangeListener;
import com.teamscale.ide.commons.util.EventListenableBase;

/**
 * Manages server states and broadcasts changes to registered
 * {@link IServerStateChangeListener}s.
 */
public class ServerStateBroadcastService extends EventListenableBase<IServerStateChangeListener>
		implements IServerStateBroadcastService {

	/** Map holding server states. */
	private final ConcurrentMap<NamedServerDetails, ETeamscaleServerState> serverStateMap = new ConcurrentHashMap<>();

	@Override
	public void updateServerState(NamedServerDetails serverDetails, ETeamscaleServerState state) {
		ETeamscaleServerState nonNullState = Objects.requireNonNull(state);
		serverStateMap.put(serverDetails, nonNullState);

		notifyListeners(
				serverStateChangeListener -> serverStateChangeListener.stateChanged(serverDetails, nonNullState));
	}

	@Override
	public Optional<ETeamscaleServerState> getServerState(NamedServerDetails serverDetails) {
		return Optional.ofNullable(serverStateMap.get(serverDetails));
	}
}
