/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright (c) 2009-2020 CQSE GmbH                                        |
|                                                                          |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.commons.util;

import java.util.EventListener;
import java.util.LinkedList;
import java.util.List;
import java.util.function.Consumer;

/**
 * Thread-safe default implementation of the {@link IEventListenable} interface.
 */
public class EventListenableBase<T extends EventListener> implements IEventListenable<T> {

	/** Listeners that need to be notified on update */
	private final List<T> listeners = new LinkedList<>();

	@Override
	public void addListener(T listener) {
		synchronized (listeners) {
			listeners.add(listener);
		}

	}

	@Override
	public void removeListener(T listener) {
		synchronized (listeners) {
			listeners.remove(listener);
		}
	}

	/**
	 * Invokes the given {@link Consumer} once for each registered
	 * {@link EventListener}.
	 */
	protected void notifyListeners(Consumer<T> consumer) {
		synchronized (listeners) {
			listeners.forEach(consumer);
		}
	}
}
