/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.util;

import java.util.Objects;

/**
 * A collection of two Teamscale-server versions, which represents a valid
 * version range.
 */
public class TeamscaleVersionRange {
	/**
	 * Minimum version supported by the Teamscale server (inclusive).
	 */
	public final TeamscaleVersion minInclusive;

	/**
	 * Maximum version supported by the Teamscale server (inclusive). I.e., this is
	 * the release version of the Teamscale server.
	 */
	public final TeamscaleVersion maxInclusive;

	public TeamscaleVersionRange(TeamscaleVersion minInclusive, TeamscaleVersion maxInclusive) {
		this.maxInclusive = Objects.requireNonNull(maxInclusive);
		this.minInclusive = Objects.requireNonNull(minInclusive);
	}

	/**
	 * Checks if the target version is inside the version range.
	 *
	 * @return True if it is in the given version range.
	 */
	public boolean isInRange(TeamscaleVersion targetVersion) {
		if (targetVersion.compareTo(minInclusive) < 0) {
			// target version is smaller than the minimum version in this range
			return false;
		}
		if (targetVersion.compareTo(maxInclusive) > 0) {
			// target version is greater than the maximum version in this range
			return false;
		}
		return true;
	}
}
