/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.commons.util;

import java.net.URI;
import java.util.List;

import com.google.common.base.Joiner;
import com.google.common.base.Splitter;
import com.google.common.collect.Lists;
import com.google.common.net.UrlEscapers;

/**
 * Utilities for working with paths as produced by different IDEs or
 * version-control system implementations.
 */
public class UriPathUtils {

	/**
	 * Given a path with slashes as separator, returns a path that can be used as an
	 * absolute path in a {@link URI}.
	 */
	public static String toAbsoluteUriPath(String absoluteFilePath) {
		String absoluteUriPath = toRelativeUriPath(absoluteFilePath);
		if (!absoluteUriPath.startsWith("/")) {
			return "/" + absoluteUriPath;
		}
		return absoluteUriPath;
	}

	/**
	 * Given a path with slashes as separator, returns a path that can be used as a
	 * relative path in a {@link URI}.
	 */
	public static String toRelativeUriPath(String relativeFilePath) {
		List<String> pathComponents = Splitter.on('/').splitToList(relativeFilePath);
		List<String> escapedPathComponents = Lists.transform(pathComponents,
				UrlEscapers.urlPathSegmentEscaper()::escape);
		return Joiner.on('/').join(escapedPathComponents);
	}
}
