/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.teamscale.ide.commons.vcs;

import java.net.URI;
import java.util.Objects;

import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * Revision descriptor class to store a pair of revision identifier and
 * repository URI. A repository URI is optional and only used to differentiate
 * revisions in different repositories with equal revision identifiers.
 */
public final class RevisionDescriptor {

	/** Revision number */
	private final String revisionIdentifier;
	/** Repository URI */
	private final URI repositoryUri;

	/** Constructor, that only sets the revision identifier. */
	public RevisionDescriptor(String revisionIdentifier) {
		this(revisionIdentifier, null);
	}

	public RevisionDescriptor(String revisionIdentifier, URI repositoryUri) {
		this.revisionIdentifier = Objects.requireNonNull(revisionIdentifier);
		this.repositoryUri = repositoryUri;
	}

	public String getRevision() {
		return revisionIdentifier;
	}

	public URI getRepositoryUri() {
		return repositoryUri;
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}

	@Override
	public boolean equals(Object o) {
		if (this == o) {
			return true;
		}
		if (o == null || getClass() != o.getClass()) {
			return false;
		}
		RevisionDescriptor that = (RevisionDescriptor) o;
		return revisionIdentifier.equals(that.revisionIdentifier) && Objects.equals(repositoryUri, that.repositoryUri);
	}

	@Override
	public int hashCode() {
		return Objects.hash(revisionIdentifier, repositoryUri);
	}
}
