package com.teamscale.ide.config;

import java.nio.file.Path;

/**
 * Thrown when a Teamscale configuration (.toml) file is invalid, or cannot be
 * parsed or read.
 */
public class InvalidConfigException extends Exception {

	private static final long serialVersionUID = 1L;

	/** Path to the (innermost) invalid Teamscale configuration file. **/
	private final Path invalidTeamscaleTomlFile;

	/**
	 * Constructs an {@link InvalidConfigException} with the given message and
	 * cause.
	 */
	public InvalidConfigException(Path invalidTeamscaleTomlFile, String message, Throwable cause) {
		super(message, cause);
		this.invalidTeamscaleTomlFile = invalidTeamscaleTomlFile;
	}

	/** Constructs an {@link InvalidConfigException} with the given message. */
	public InvalidConfigException(Path invalidTeamscaleTomlFile, String message) {
		super(message);
		this.invalidTeamscaleTomlFile = invalidTeamscaleTomlFile;
	}

	/** Returns a path to the invalid .toml configuration file **/
	public Path getInvalidTomlFile() {
		return invalidTeamscaleTomlFile;
	}
}