package com.teamscale.ide.eclipse;

/**
 * A collection of IDs that are defined by this plug-in.
 */
public class EclipseIds {

	/**
	 * The plug-in ID.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code MANIFEST.MF}: {@code Bundle-SymbolicName} attribute</li>
	 * <li><i>...many more...</i></li>
	 * </ul>
	 */
	public static final String PLUGIN = "com.teamscale.ide";

	/**
	 * A collection of command IDs that are defined by this plug-in.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code fragment.e4xmi}: {@code commands} model fragment</li>
	 * <li>{@code plugin.xml}: {@code org.eclipse.ui.commands} extension point
	 * (legacy IDs)</li>
	 * </ul>
	 * 
	 * @see org.eclipse.e4.core.commands.ECommandService
	 */
	public static class Commands {

		/** The "Flag Finding as False-Positive" command ID. */
		public static final String FLAG_FINDING_AS_FALSE_POSITIVE = "com.teamscale.ide.eclipse.commands.flagFindingAsFalsePositive";

		/** The "Flag Finding as Tolerated" command ID. */
		public static final String FLAG_FINDING_AS_TOLERATED = "com.teamscale.ide.eclipse.commands.flagFindingAsTolerated";

		/** The "Open in Editor" command ID. */
		public static final String OPEN_IN_EDITOR = "com.teamscale.ide.eclipse.commands.openInEditor";

		/** The "Open Finding in Editor" command ID. */
		public static final String OPEN_FINDING_IN_EDITOR = "com.teamscale.ide.eclipse.commands.openFindingInEditor";

		/** The "Open in Web Browser" command ID. */
		public static final String OPEN_IN_BROWSER = "com.teamscale.ide.eclipse.commands.openInBrowser";

		/** The "Open Finding in Web Browser" command ID. */
		public static final String OPEN_FINDING_IN_BROWSER = "com.teamscale.ide.eclipse.commands.openFindingInBrowser";

		/** The "Open Resource in Web Browser" command ID. */
		public static final String OPEN_RESOURCE_IN_BROWSER = "com.teamscale.ide.eclipse.commands.openResourceInBrowser";

		/** The "Open Remote Resource in Web Browser" command ID. */
		public static final String OPEN_REMOTE_RESOURCE_IN_BROWSER = "com.teamscale.ide.eclipse.commands.openRemoteResourceInBrowser";

		/** The "Open Editor Contents in Web Browser" command ID. */
		public static final String OPEN_EDITOR_CONTENTS_IN_BROWSER = "com.teamscale.ide.eclipse.commands.openEditorContentsInBrowser";

		/** The "Open Check Description" command ID. */
		public static final String OPEN_CHECK_DESCRIPTION = "com.teamscale.ide.eclipse.commands.openCheckDescription";

		/** The "Enable Automatic Pre-Commit Analysis" (legacy) command ID. */
		public static final String AUTOMATIC_PRE_COMMIT_ANALYSIS = "com.teamscale.ide.automaticPreCommitAnalysis";

		/** The "Refresh Findings" (legacy) command ID. */
		public static final String REFRESH_FINDINGS = "com.teamscale.ide.refreshFindings";

		/** The "Open Server Preferences" (legacy) command ID. */
		public static final String OPEN_SERVER_PREFERENCES = "com.teamscale.ide.openServerPreferences";
	}

	/**
	 * A collection of handler IDs that are defined by this plug-in.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code fragment.e4xmi}: {@code handlers} model fragment</li>
	 * </ul>
	 * 
	 * @see org.eclipse.e4.core.commands.EHandlerService
	 */
	public static class Handlers {

		/** The "Flag Finding as False-Positive" handler ID. */
		public static final String FLAG_FINDING_AS_FALSE_POSITIVE = "com.teamscale.ide.eclipse.handlers.flagFindingAsFalsePositive";

		/** The "Flag Finding as Tolerated" handler ID. */
		public static final String FLAG_FINDING_AS_TOLERATED = "com.teamscale.ide.eclipse.handlers.flagFindingAsTolerated";

		/** The "Open in Editor" handler ID. */
		public static final String OPEN_IN_EDITOR = "com.teamscale.ide.eclipse.handlers.openInEditor";

		/** The "Open Finding in Editor" handler ID. */
		public static final String OPEN_FINDING_IN_EDITOR = "com.teamscale.ide.eclipse.handlers.openFindingInEditor";

		/** The "Open in Web Browser" handler ID. */
		public static final String OPEN_IN_BROWSER = "com.teamscale.ide.eclipse.handlers.openInBrowser";

		/** The "Open Finding in Web Browser" handler ID. */
		public static final String OPEN_FINDING_IN_BROWSER = "com.teamscale.ide.eclipse.handlers.openFindingInBrowser";

		/** The "Open Resource in Web Browser" handler ID. */
		public static final String OPEN_RESOURCE_IN_BROWSER = "com.teamscale.ide.eclipse.handlers.openResourceInBrowser";

		/** The "Open Remote Resource in Web Browser" handler ID. */
		public static final String OPEN_REMOTE_RESOURCE_IN_BROWSER = "com.teamscale.ide.eclipse.handlers.openRemoteResourceInBrowser";

		/** The "Open Editor Contents in Web Browser" handler ID. */
		public static final String OPEN_EDITOR_CONTENTS_IN_BROWSER = "com.teamscale.ide.eclipse.handlers.openEditorContentsInBrowser";

		/** The "Open Check Description" handler ID. */
		public static final String OPEN_CHECK_DESCRIPTION = "com.teamscale.ide.eclipse.handlers.openCheckDescription";

	}

	/**
	 * A collection of part/view IDs that are defined by this plug-in.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code fragment.e4xmi}: {@code descriptors} model fragment</li>
	 * <li>{@code plugin.xml}: {@code org.eclipse.ui.views} extension point (legacy
	 * IDs)</li>
	 * </ul>
	 */
	public static class Parts {

		/** The "Findings" (legacy) view ID. */
		public static final String FINDINGS = "com.teamscale.ide.findingsView";

		/** The "Check Descriptions" part descriptor ID. */
		public static final String CHECK_DESCRIPTIONS = "com.teamscale.ide.eclipse.descriptors.checkDescriptions";
	}

	/**
	 * A collection of preference-page IDs that are defined by this plug-in.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code fragment.e4xmi}: {@code parameters} elements</li>
	 * <li>{@code plugin.xml}: {@code org.eclipse.ui.preferencePages} extension
	 * point (legacy IDs)</li>
	 * </ul>
	 */
	public static class PreferencePages {

		/** The "Teamscale" (legacy) preference page ID */
		public static final String TEAMSCALE = "com.teamscale.ide.IndexServerPreferencePage";
	}

	/**
	 * A collection of property-page IDs that are defined by this plug-in.
	 * <p>
	 * Needs to be kept in-sync with the following places:
	 * <ul>
	 * <li>{@code fragment.e4xmi}: {@code parameters} elements</li>
	 * <li>{@code plugin.xml}: {@code org.eclipse.ui.propertyPages} extension point
	 * (legacy IDs)</li>
	 * </ul>
	 */
	public static class PropertyPages {

		/** The "Teamscale" (legacy) property page ID */
		public static final String TEAMSCALE = "com.teamscale.ide.properties.TeamscaleResourceMappingPropertyPage";
	}
}
