/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse;

import java.beans.PropertyChangeListener;

import org.osgi.framework.BundleContext;
import org.osgi.framework.FrameworkUtil;

/**
 * A Java bean that stores user-interface preferences for the plugin.
 * {@link PropertyChangeListener}s can be registered and will be informed about
 * changes to the following properties, i.e., user-interface preferences:
 * <ul>
 * <li>{@link #AUTOMATIC_PRE_COMMIT_ANALYSIS_ENABLED}</li>
 * </ul>
 */
public interface IUiPreferences {
	
	/** Name of the {@value #AUTOMATIC_PRE_COMMIT_ANALYSIS_ENABLED} property. */
	String AUTOMATIC_PRE_COMMIT_ANALYSIS_ENABLED = "automaticPreCommitAnalysisEnabled";

	/**
	 * Whether to automatically run pre-commit analysis when users save changes or
	 * switch to another file. Users might want to disable it to reduce the load on
	 * the server (or on their network). (This setting is preserved across IDE
	 * restarts.)
	 */
	boolean isAutomaticPreCommitAnalysisEnabled();

	/**
	 * Sets whether to automatically run pre-commit analysis when users save changes or
	 * switch to another file. Users might want to disable it to reduce the load on
	 * the server (or on their network). (This setting is preserved across IDE
	 * restarts.)
	 */ 
	void setAutomaticPreCommitAnalysisEnabled(boolean automaticPreCommitAnalysisEnabled);

	/** Adds a {@link PropertyChangeListener}. */
	void addPropertyChangeListener(PropertyChangeListener listener);

	/** Removes a {@link PropertyChangeListener}. */
	void removePropertyChangeListener(PropertyChangeListener listener);
	
	/**
	 * Used to get the singleton instance of the OSGi service from non-E4 code (in
	 * E4 code it can simply be injected). Should eventually be phased out.
	 */
	static IUiPreferences getInstance() {
		BundleContext bundleContext = FrameworkUtil.getBundle(IUiPreferences.class).getBundleContext();
		return bundleContext.getService(bundleContext.getServiceReference(IUiPreferences.class));
	}
}
