/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse;

import java.net.MalformedURLException;
import java.net.URL;

import org.eclipse.jface.resource.ImageDescriptor;

/**
 * A collection of {@code platform:} URLs for icon resources in this Eclipse
 * plug-in.
 *
 * Paths follow the naming conventions laid out in the Eclipse <a href=
 * "https://wiki.eclipse.org/User_Interface_Guidelines#Graphic_Types">User
 * Interface Guidelines</a>.
 */
public class Icons {

	/**
	 * An icon for the "Findings" view.
	 */
	public static final ImageDescriptor FINDINGS_VIEW_ICON = createImageDescriptor("icons/view16/findings.png");

	/**
	 * An icon signifying a Web browser.
	 *
	 * Taken from {@code org.eclipse.ui.browser}'s <a href=
	 * "https://github.com/eclipse-platform/eclipse.platform.images/blob/master/org.eclipse.images/eclipse-png/org.eclipse.ui.browser/icons/obj16/external_browser.png"><code>external_browser</code></a>
	 * overlay.
	 */
	public static final ImageDescriptor BROWSER_ICON = createImageDescriptor("icons/obj16/browser.png");

	/**
	 * An icon signifying a "go to editor" action.
	 *
	 * Taken from {@code org.eclipse.search}'s <a href=
	 * "https://github.com/eclipse-platform/eclipse.platform.images/blob/master/org.eclipse.images/eclipse-png/org.eclipse.search/icons/full/elcl16/search_goto.png"><code>search_goto</code></a>
	 * overlay.
	 */
	public static final ImageDescriptor GO_TO_EDITOR = createImageDescriptor("icons/elcl16/go-to-editor.png");

	/**
	 * An icon signifying a "refresh" action.
	 *
	 * Taken from {@code org.eclipse.search}'s <a href=
	 * "https://github.com/eclipse-platform/eclipse.platform.images/blob/master/org.eclipse.images/eclipse-png/org.eclipse.search/icons/full/elcl16/refresh.png"><code>refresh</code></a>
	 * icon.
	 */
	public static final ImageDescriptor REFRESH = createImageDescriptor("icons/elcl16/refresh.png");

	/**
	 * An overlay (i.e., quarter-size icon) signifying that something has been or
	 * will be added.
	 *
	 * Taken from {@code org.eclipse.egit.ui}'s <a href=
	 * "https://git.eclipse.org/c/egit/egit.git/tree/org.eclipse.egit.ui/icons/ovr/staged_added.png"><code>staged_added</code></a>
	 * overlay.
	 */
	public static final ImageDescriptor ADDED_OVERLAY = createImageDescriptor("icons/ovr16/added.png");

	private static ImageDescriptor createImageDescriptor(String resourcePath) {
		return ImageDescriptor.createFromURL(createUrl(resourcePath));
	}

	private static URL createUrl(String resourcePath) {
		try {
			return new URL(String.format("platform:/plugin/%s/%s", EclipseIds.PLUGIN, resourcePath));
		} catch (MalformedURLException e) {
			throw new AssertionError(e);
		}
	}
}
