/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse;

import java.beans.PropertyChangeListener;
import java.beans.PropertyChangeSupport;

import com.teamscale.ide.commons.lang.ToStringHelpers;

/**
 * An implementation of {@link IUiPreferences}. It is both a Java bean and an
 * OSGi service, registered in {@code OSGI-INF/uiPreferences.xml}.
 */
public class UiPreferences implements IUiPreferences {

	private final PropertyChangeSupport changeSupport = new PropertyChangeSupport(this);

	private boolean automaticPreCommitAnalysisEnabled = true;

	@Override
	public boolean isAutomaticPreCommitAnalysisEnabled() {
		return automaticPreCommitAnalysisEnabled;
	}

	@Override
	public void setAutomaticPreCommitAnalysisEnabled(boolean automaticPreCommitAnalysisEnabled) {
		changeSupport.firePropertyChange(AUTOMATIC_PRE_COMMIT_ANALYSIS_ENABLED, this.automaticPreCommitAnalysisEnabled,
				this.automaticPreCommitAnalysisEnabled = automaticPreCommitAnalysisEnabled);
	}

	@Override
	public void addPropertyChangeListener(PropertyChangeListener listener) {
		changeSupport.addPropertyChangeListener(listener);
	}

	@Override
	public void removePropertyChangeListener(PropertyChangeListener listener) {
		changeSupport.removePropertyChangeListener(listener);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
