package com.teamscale.ide.eclipse.findings;

import java.util.Set;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.conqat.ide.commons.ui.logging.LoggingUtils;
import org.eclipse.core.resources.IResourceChangeEvent;
import org.eclipse.core.resources.IResourceChangeListener;
import org.eclipse.core.resources.IResourceDelta;
import org.eclipse.core.runtime.CoreException;

import com.teamscale.ide.TeamscaleIDEActivator;
import com.teamscale.ide.commons.findings.tasks.FetchFindingsTask;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.notification.ENotificationCause;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.ITaskExecutor;

/**
 * Listens to file deletions.
 */
public class FileDeleteListener implements IResourceChangeListener {

	private static final Logger LOGGER = LogManager.getLogger();

	private final ITaskExecutor taskExecutor;
	private final IServiceRegistry serviceRegistry;

	public FileDeleteListener(IServiceRegistry serviceRegistry) {
		this.serviceRegistry = serviceRegistry;
		taskExecutor = serviceRegistry.getService(ITaskExecutor.class);
	}

	@Override
	public void resourceChanged(IResourceChangeEvent event) {
		ChangeDeltaVisitor visitor = new ChangeDeltaVisitor();
		try {
			IResourceDelta delta = event.getDelta();
			if (delta != null) {
				delta.accept(visitor);
			}
		} catch (CoreException e) {
			LoggingUtils.error(TeamscaleIDEActivator.getDefault(), e);
		}

		Set<ResourceReference> deletedFiles = visitor.getRemovedFiles();
		if (deletedFiles.isEmpty()) {
			return;
		}
		LOGGER.debug("Files have been deleted: {}", deletedFiles);

		taskExecutor.execute(
				FetchFindingsTask.createPreCommitTask(serviceRegistry, deletedFiles, ENotificationCause.INDIRECT));
	}
}
