package com.teamscale.ide.eclipse.findings;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.viewers.DecorationOverlayIcon;
import org.eclipse.jface.viewers.IDecoration;
import org.eclipse.ui.ISharedImages;
import org.eclipse.ui.PlatformUI;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.eclipse.Icons;

/** A utility class to create icons for findings. */
public class FindingIcons {

	/**
	 * Determine the appropriate icon for a finding, including information whether
	 * it exists on a pre-commit branch or not.
	 */
	public static ImageDescriptor getImageDescriptor(Finding finding) {
		ImageDescriptor baseImage = getBaseImageDescriptor(finding);

		if (!finding.getBaseBranch().isPresent()) {
			return new DecorationOverlayIcon(baseImage, Icons.ADDED_OVERLAY, IDecoration.BOTTOM_RIGHT);
		}

		return baseImage;
	}

	/**
	 * Determine the appropriate icon for a finding, solely based on its severity.
	 */
	public static ImageDescriptor getBaseImageDescriptor(Finding finding) {
		ISharedImages sharedImages = PlatformUI.getWorkbench().getService(ISharedImages.class);
		switch (finding.getAssessment()) {
		case YELLOW:
			return sharedImages.getImageDescriptor(ISharedImages.IMG_OBJS_WARN_TSK);
		case RED:
			return sharedImages.getImageDescriptor(ISharedImages.IMG_OBJS_ERROR_TSK);
		default:
			throw new IllegalArgumentException(finding.getAssessment().name());
		}
	}
}
