package com.teamscale.ide.eclipse.findings;

import java.util.List;

import org.eclipse.jface.layout.GridDataFactory;
import org.eclipse.jface.layout.GridLayoutFactory;
import org.eclipse.jface.resource.JFaceResources;
import org.eclipse.jface.resource.LocalResourceManager;
import org.eclipse.jface.resource.ResourceManager;
import org.eclipse.jface.text.AbstractInformationControl;
import org.eclipse.jface.text.IInformationControlExtension2;
import org.eclipse.swt.SWT;
import org.eclipse.swt.custom.StyledText;
import org.eclipse.swt.graphics.Color;
import org.eclipse.swt.graphics.Point;
import org.eclipse.swt.graphics.RGB;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Control;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Shell;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.eclipse.util.markdown.MarkdownTextStyler;

/**
 * An information control capable of showing findings.
 */
public class FindingsInformationControl extends AbstractInformationControl implements IInformationControlExtension2 {

	private final ResourceManager resourceManager = new LocalResourceManager(JFaceResources.getResources());
	private Composite parent;

	public FindingsInformationControl(Shell parentShell) {
		super(parentShell, false);
		create();
	}

	@Override
	public void dispose() {
		resourceManager.dispose();
	}

	@Override
	public boolean hasContents() {
		return true;
	}

	@Override
	protected void createContent(Composite parent) {
		this.parent = parent;
	}

	@Override
	public void setInput(Object input) {
		@SuppressWarnings("unchecked")
		List<Finding> findings = (List<Finding>) input;
		deferredCreateContent(findings);
	}

	private void deferredCreateContent(List<Finding> findings) {
		Composite grid = new Composite(parent, SWT.NO_FOCUS);

		GridLayoutFactory.swtDefaults().numColumns(2).applyTo(grid);

		for (Finding finding : findings) {
			Label icon = new Label(grid, SWT.LEFT);
			GridDataFactory.fillDefaults().applyTo(icon);
			icon.setImage(resourceManager.createImage(FindingIcons.getImageDescriptor(finding)));

			StyledText label = new StyledText(grid, SWT.LEFT);
			GridDataFactory.fillDefaults().applyTo(label);
			Color teamscaleColor = resourceManager.createColor(new RGB(204, 120, 50));
			new MarkdownTextStyler(finding.getMessage(), parent.getForeground(), teamscaleColor).style(label);
		}

		propagateBackgroundColor(parent);
	}

	/**
	 * Sets the color of all of the composite's children to its color
	 */
	private static void propagateBackgroundColor(Composite composite) {
		Control[] children = composite.getChildren();
		for (Control child : children) {
			child.setBackground(composite.getBackground());
			if (child instanceof Composite) {
				propagateBackgroundColor((Composite) child);
			}
		}
	}

	@Override
	public Point computeSizeHint() {
		// Let the parent compute the minimal size to display its children.
		return parent.computeSize(SWT.DEFAULT, SWT.DEFAULT);
	}

}
