
/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.findings.handlers;

import javax.inject.Inject;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.findings.tasks.FlagFindingAsFalsePositiveTask;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.TaskBase;
import com.teamscale.ide.eclipse.util.handlers.AdaptingSelectionHandlerBase;

/**
 * An action that, given a single selected {@link Finding}, offers to flag
 * (black-list) it as a false positive.
 */
public class FlagFindingAsFalsePositiveHandler extends BlacklistFindingHandlerBase {

	@Inject
	public FlagFindingAsFalsePositiveHandler(IServiceRegistry serviceRegistry) {
		super(serviceRegistry, "Flag Finding as False Positive");
	}

	@Override
	protected TaskBase createBlacklistTask(IServiceRegistry serviceRegistry, Finding finding, String rationale) {
		return new FlagFindingAsFalsePositiveTask(serviceRegistry, finding, rationale);
	}

	/**
	 * @see FlagFindingAsFalsePositiveHandler
	 */
	public static class AdaptingHandler extends AdaptingSelectionHandlerBase<Finding> {

		public AdaptingHandler() {
			super(FlagFindingAsFalsePositiveHandler.class, Finding.class);
		}
	}

}
