package com.teamscale.ide.eclipse.findings.handlers;

import javax.inject.Inject;
import javax.inject.Named;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.ui.model.application.ui.basic.MPart;
import org.eclipse.e4.ui.services.IServiceConstants;
import org.eclipse.e4.ui.workbench.modeling.EPartService;
import org.eclipse.e4.ui.workbench.modeling.EPartService.PartState;

import com.teamscale.ide.commons.findings.Finding;
import com.teamscale.ide.commons.findings.tasks.FetchCheckDescriptionTask;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.ITaskExecutor;
import com.teamscale.ide.eclipse.EclipseIds;
import com.teamscale.ide.eclipse.findings.descriptions.CheckDescriptionsPart;
import com.teamscale.ide.eclipse.util.handlers.AdaptingSelectionHandlerBase;

/**
 * A handler that, given a single selected {@link Finding}, fetches the
 * description of the check that created it and shows it in the
 * {@linkplain CheckDescriptionsPart "Check Descriptions" view} (opening it
 * if necessary).
 */
public class OpenCheckDescriptionHandler {

	private static final Logger LOGGER = LogManager.getLogger();

	private final EPartService partService;
	private final IServiceRegistry serviceRegistry;
	private final ITaskExecutor taskExecutor;

	@Inject
	public OpenCheckDescriptionHandler(IServiceRegistry serviceRegistry, EPartService partService) {
		this.partService = partService;

		this.serviceRegistry = serviceRegistry;
		taskExecutor = serviceRegistry.getService(ITaskExecutor.class);
	}

	@Execute
	public void execute(@Named(IServiceConstants.ACTIVE_SELECTION) Finding finding) {
		LOGGER.traceEntry(null, finding);
		openPart(EclipseIds.Parts.CHECK_DESCRIPTIONS);
		taskExecutor.execute(new FetchCheckDescriptionTask(serviceRegistry, finding));
		LOGGER.traceExit();
	}

	private void openPart(String partId) {
		MPart part = partService.findPart(partId);
		if (part == null) {
			part = partService.createPart(partId);
		}
		partService.showPart(part, PartState.VISIBLE);
	}

	/**
	 * @see OpenCheckDescriptionHandler
	 */
	public static class AdaptingHandler extends AdaptingSelectionHandlerBase<Finding> {

		public AdaptingHandler() {
			super(OpenCheckDescriptionHandler.class, Finding.class);
		}
	}
}
