/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.handlers;

import javax.inject.Inject;

import org.eclipse.e4.ui.model.application.MApplication;
import org.eclipse.e4.ui.workbench.modeling.EModelService;

import com.teamscale.ide.eclipse.EclipseIds;
import com.teamscale.ide.eclipse.util.handlers.DispatchingHandlerBase;

/**
 * A generic handler that acts as a dispatcher for other, concrete handlers of
 * an "Open in Web Browser" command.
 * <p>
 * When "in windows", the associated command is bound to Ctrl+Shift+F2 (or
 * Cmd+Shift+F2 on macOS), alluding to the key binding of the "Open Attached
 * Javadoc (in Browser)" command.
 */
public class OpenInBrowserDispatchingHandler extends DispatchingHandlerBase {

	@Inject
	public OpenInBrowserDispatchingHandler(MApplication application, EModelService modelService) {
		super(application, modelService, EclipseIds.Commands.OPEN_FINDING_IN_BROWSER,
				EclipseIds.Commands.OPEN_RESOURCE_IN_BROWSER, EclipseIds.Commands.OPEN_REMOTE_RESOURCE_IN_BROWSER);
	}
}
