/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.mappings.handlers;

import javax.inject.Inject;
import javax.inject.Named;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.ui.services.IServiceConstants;

import com.teamscale.ide.commons.mappings.tasks.OpenRemoteResourceInBrowserTask;
import com.teamscale.ide.commons.model.RemoteResourceReference;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.ITaskExecutor;
import com.teamscale.ide.eclipse.util.handlers.AdaptingSelectionHandlerBase;

/**
 * A handler that, given a single selected {@code RemoteResourceReference},
 * opens the configured default browser to view the corresponding resource on
 * the Teamscale server.
 */
public class OpenRemoteResourceInBrowserHandler {

	private static final Logger LOGGER = LogManager.getLogger();

	private final IServiceRegistry serviceRegistry;
	private final ITaskExecutor taskExecutor;

	@Inject
	public OpenRemoteResourceInBrowserHandler(IServiceRegistry serviceRegistry) {
		this.serviceRegistry = serviceRegistry;
		taskExecutor = serviceRegistry.getService(ITaskExecutor.class);
	}

	@Execute
	public void execute(@Named(IServiceConstants.ACTIVE_SELECTION) RemoteResourceReference remoteResource) {
		LOGGER.traceEntry(null, remoteResource);
		taskExecutor.execute(new OpenRemoteResourceInBrowserTask(serviceRegistry, remoteResource));
		LOGGER.traceExit();
	}

	/** @see OpenRemoteResourceInBrowserHandler */
	public static class AdaptingHandler extends AdaptingSelectionHandlerBase<RemoteResourceReference> {

		public AdaptingHandler() {
			super(OpenRemoteResourceInBrowserHandler.class, RemoteResourceReference.class);
		}
	}
}
