/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.mappings.handlers;

import javax.inject.Inject;
import javax.inject.Named;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.core.resources.IResource;
import org.eclipse.e4.core.di.annotations.Execute;
import org.eclipse.e4.ui.services.IServiceConstants;

import com.teamscale.ide.commons.mappings.tasks.OpenResourceInBrowserTask;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.ITaskExecutor;
import com.teamscale.ide.eclipse.model.ResourceReferences;
import com.teamscale.ide.eclipse.util.handlers.SingleResourceCompabilitySelectionHandlerBase;

/**
 * A handler that, given a single selected {@code IResource}, opens the
 * configured default browser to view the corresponding resource on the
 * Teamscale server.
 */
public class OpenResourceInBrowserHandler {

	private static final Logger LOGGER = LogManager.getLogger();

	private final IServiceRegistry serviceRegistry;
	private final ITaskExecutor taskExecutor;

	@Inject
	public OpenResourceInBrowserHandler(IServiceRegistry serviceRegistry) {
		this.serviceRegistry = serviceRegistry;
		taskExecutor = serviceRegistry.getService(ITaskExecutor.class);
	}

	@Execute
	public void execute(@Named(IServiceConstants.ACTIVE_SELECTION) IResource resource) {
		LOGGER.traceEntry(null, resource);
		ResourceReference resourceReference = ResourceReferences.fromIResource(resource).orElse(null);
		if (resourceReference == null) {
			return;
		}
		
		taskExecutor.execute(
				new OpenResourceInBrowserTask(serviceRegistry, resourceReference));
		LOGGER.traceExit();
	}

	/**
	 * @see OpenResourceInBrowserHandler
	 */
	public static class CompatibilityHandler extends SingleResourceCompabilitySelectionHandlerBase {

		public CompatibilityHandler() {
			super(OpenResourceInBrowserHandler.class);
		}
	}
}
