/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.model;

import java.util.Objects;

import org.eclipse.core.resources.IProject;

import com.teamscale.ide.commons.lang.ToStringHelpers;
import com.teamscale.ide.commons.model.IIDEProject;
import com.teamscale.ide.commons.model.ResourceReference;

/**
 * Wrapper around Eclipse {@link IProject}.
 */
public class EclipseProject implements IIDEProject {

	private final IProject project;

	public EclipseProject(IProject project) {
		this.project = project;
	}

	@Override
	public ResourceReference getRootDirectory() {
		return ResourceReferences.fromIResource(project).orElse(null);
	}

	@Override
	public IProject getProject() {
		return project;
	}

	@Override
	public boolean equals(Object other) {
		if (this == other) {
			return true;
		}
		if (other == null) {
			return false;
		}
		if (getClass() != other.getClass()) {
			return false;
		}
		EclipseProject that = (EclipseProject) other;
		return Objects.equals(this.project, that.project);
	}

	@Override
	public int hashCode() {
		return Objects.hash(project);
	}

	@Override
	public String toString() {
		return ToStringHelpers.toReflectiveStringHelper(this).toString();
	}
}
