/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.model;

import java.net.URI;
import java.util.Optional;

import org.checkerframework.checker.nullness.qual.Nullable;
import org.eclipse.core.resources.IResource;

import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.util.UriUtils;

/**
 * Helper methods to create IDE Commons {@link ResourceReference}s from
 * IDE-specific types.
 */
public class ResourceReferences {

	/** Converts the given {@link IResource} into a {@link ResourceReference}. */
	public static Optional<ResourceReference> fromIResource(@Nullable IResource resource) {
		if (resource == null) {
			return Optional.empty();
		}
		URI uri = resource.getLocationURI();
		if (resource.getType() == IResource.FILE) {
			return Optional.of(ResourceReference.forFile(uri));
		}
		return Optional.of(ResourceReference.forFolder(UriUtils.ensurePathHasTrailingSlash(uri)));
	}
}
