/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.plugin.services;

import java.net.MalformedURLException;
import java.net.URI;
import java.util.concurrent.atomic.AtomicBoolean;

import org.apache.logging.log4j.LogManager;
import org.apache.logging.log4j.Logger;
import org.eclipse.swt.widgets.Display;
import org.eclipse.ui.PartInitException;
import org.eclipse.ui.PlatformUI;

import com.teamscale.ide.commons.plugin.services.IWebBrowserService;

/**
 * Eclipse-specific implementation of {@link IWebBrowserService}.
 */
public class EclipseWebBrowserService implements IWebBrowserService {

	private static final Logger LOGGER = LogManager.getLogger();

	@Override
	public boolean open(URI uri) {
		LOGGER.traceEntry(null, uri);
		try {
			AtomicBoolean result = new AtomicBoolean();
			Display.getDefault().syncExec(() -> result.set(doOpen(uri)));
			return LOGGER.traceExit(result.get());
		} finally {
			LOGGER.traceExit();
		}
	}

	private boolean doOpen(URI uri) {
		LOGGER.traceEntry(null, uri);
		try {
			PlatformUI.getWorkbench().getBrowserSupport().getExternalBrowser().openURL(uri.toURL());
			return LOGGER.traceExit(true);
		} catch (PartInitException | MalformedURLException e) {
			LOGGER.catching(e);
			return LOGGER.traceExit(false);
		}
	}
}
