/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.util.contexts;

import java.lang.annotation.Annotation;

import org.eclipse.e4.core.contexts.ContextInjectionFactory;
import org.eclipse.e4.core.contexts.EclipseContextFactory;
import org.eclipse.e4.core.contexts.IEclipseContext;
import org.eclipse.e4.ui.services.IServiceConstants;

/**
 * Utility methods for working with Eclipse 4 injection.
 */
public class InjectionUtils {

	/**
	 * {@linkplain ContextInjectionFactory#make(Class, IEclipseContext) Creates} an
	 * instance of the given {@code receiverClass} and
	 * {@linkplain ContextInjectionFactory#invoke(Object, Class, IEclipseContext, Object)
	 * invokes} the method annotated with the given {@code qualifier} on it, with
	 * {@code selection} replacing the
	 * {@linkplain IServiceConstants#ACTIVE_SELECTION active selection}.
	 * 
	 * @see ContextInjectionFactory#make(Class, IEclipseContext)
	 * @see ContextInjectionFactory#invoke(Object, Class, IEclipseContext, Object)
	 */
	public static Object makeAndInvokeWithSelection(Class<?> receiverClass, Class<? extends Annotation> qualifier,
			IEclipseContext context, Object selection, Object defaultValue) {
		Object handler = ContextInjectionFactory.make(receiverClass, context);
		IEclipseContext localContext = EclipseContextFactory.create();
		localContext.set(IServiceConstants.ACTIVE_SELECTION, selection);
		return ContextInjectionFactory.invoke(handler, qualifier, context, localContext, defaultValue);
	}
}
