/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.util.handlers;

import java.util.Optional;

import javax.inject.Inject;

import org.eclipse.core.resources.IResource;
import org.eclipse.e4.core.services.adapter.Adapter;
import org.eclipse.jface.viewers.ISelection;

import com.teamscale.ide.eclipse.util.viewers.SelectionUtils;

/**
 * A handler base class that takes an Eclipse 3 {@link ISelection} and, if it
 * contains a single {@link IResource} or something that can be
 * {@linkplain Adapter#adapt(Object, Class) adapted} to it, delegates to an
 * instance of {@code handlerClass}.
 * <p>
 * Matches the {@code com.teamscale.ide.eclipse.definitions.singleResource} core
 * expression in {@code plugin.xml}.
 */
@SuppressWarnings("restriction")
public abstract class SingleResourceCompabilitySelectionHandlerBase
		extends CompatibilitySelectionHandlerBase<IResource> {

	@Inject
	private Adapter adapter;

	protected SingleResourceCompabilitySelectionHandlerBase(Class<?> handlerClass) {
		super(handlerClass);
	}

	@Override
	protected Optional<IResource> getSelectedElement(ISelection selection) {
		return SelectionUtils.getSingleAdaptedElement(selection, adapter, IResource.class);
	}
}
