/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.util.swt;

import java.util.function.Consumer;

import org.eclipse.swt.widgets.Display;

/**
 * Utilities for working with {@link Display}s.
 */
public class DisplayUtils {

	/**
	 * Executes a display operation {@linkplain Display#asyncExec(Runnable)
	 * asynchronously}.
	 */
	public static void asyncExec(Consumer<Display> displayOperation) {
		Display.getDefault().asyncExec(() -> displayOperation.accept(Display.getCurrent()));
	}

	/**
	 * Executes a display operation {@linkplain Display#syncExec(Runnable)
	 * synchronously}.
	 */
	public static void syncExec(Consumer<Display> displayOperation) {
		Display.getDefault().syncExec(() -> displayOperation.accept(Display.getCurrent()));
	}
}
