/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.eclipse.util.ui;

import java.util.Optional;

import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.IViewPart;
import org.eclipse.ui.IWorkbenchPage;
import org.eclipse.ui.IWorkbenchPart;
import org.eclipse.ui.IWorkbenchWindow;
import org.eclipse.ui.PlatformUI;

/**
 * Utility methods related to (legacy) Eclipse 3 workbench objects (windows,
 * editors, views, etc.).
 */
public class WorkbenchUtils {

	/**
	 * Get active {@linkplain IWorkbenchWindow workbench window}, if any.
	 */
	public static Optional<IWorkbenchWindow> getActiveWorkbenchWindow() {
		return Optional.ofNullable(PlatformUI.getWorkbench().getActiveWorkbenchWindow());
	}

	/**
	 * Get active {@linkplain IWorkbenchPage workbench page}, if any.
	 */
	public static Optional<IWorkbenchPage> getActiveWorkbenchPage() {
		return getActiveWorkbenchWindow().map(IWorkbenchWindow::getActivePage);
	}

	/**
	 * Get the active {@linkplain IWorkbenchPart workbench part}, if any.
	 */
	public static Optional<IWorkbenchPart> getActiveWorkbenchPart() {
		return getActiveWorkbenchPage().map(IWorkbenchPage::getActivePart);
	}

	/**
	 * Get the {@linkplain IViewPart view} with the given ID, if any.
	 */
	public static Optional<IViewPart> getViewPart(String viewId) {
		return getActiveWorkbenchPage().map(page -> page.findView(viewId));
	}

	/**
	 * Returns the active {@linkplain Shell shell}, if any.
	 */
	public static Optional<Shell> getActiveShell() {
		return getActiveWorkbenchWindow().map(IWorkbenchWindow::getShell);
	}
}
