/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.util.viewers;

import java.util.Optional;

import org.eclipse.e4.core.services.adapter.Adapter;
import org.eclipse.jface.viewers.ISelection;
import org.eclipse.jface.viewers.IStructuredSelection;

/**
 * Utilities for working with {@link ISelection}s.
 */
@SuppressWarnings("restriction")
public final class SelectionUtils {
	
	/**
	 * @return the selected element, <strong>if</strong> exactly one element is
	 *         selected. {@link Optional#empty()} otherwise.
	 */
	public static Optional<Object> getSingleElement(ISelection selection) {
		if (!(selection instanceof IStructuredSelection)) {
			return Optional.empty();
		}

		IStructuredSelection structuredSelection = (IStructuredSelection) selection;
		if (structuredSelection.size() != 1) {
			return Optional.empty();
		}
		return Optional.of(structuredSelection.getFirstElement());
	}

	/**
	 * @return the selected element {@linkplain Adapter#adapt(Object, Class)
	 *         adapted} to the given {@code adapterType}, <strong>if</strong>
	 *         exactly one element is selected and it can be adapted to the given
	 *         type. {@link Optional#empty()} otherwise.
	 */
	public static <T> Optional<T> getSingleAdaptedElement(ISelection selection, Adapter adapter, Class<T> adapterType) {
		return getSingleElement(selection).map(source -> adapter.adapt(source, adapterType));
	}
}
