/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.eclipse.vcs.subversive;

import org.eclipse.team.svn.core.connector.SVNChangeStatus;
import org.eclipse.team.svn.core.connector.SVNEntryStatus;
import org.eclipse.team.svn.core.connector.SVNEntryStatus.Kind;

/**
 * Utility methods mirroring the methods of the same name from
 * {@link org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils}.
 */
/* package */ class SubversiveStatusUtils {

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isManaged(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isManaged(SVNChangeStatus status) {
		Kind textStatus = status.textStatus;
		return !textStatus.equals(Kind.UNVERSIONED) && !textStatus.equals(Kind.NONE)
				&& !textStatus.equals(Kind.IGNORED);
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isAdded(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isAdded(SVNChangeStatus status) {
		return status.textStatus == Kind.ADDED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isDeleted(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isDeleted(SVNChangeStatus status) {
		return status.textStatus == Kind.DELETED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isReplaced(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isReplaced(SVNChangeStatus status) {
		return status.textStatus == Kind.REPLACED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isIgnored(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isIgnored(SVNChangeStatus status) {
		return status.textStatus == SVNEntryStatus.Kind.IGNORED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isTextModified(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isTextModified(SVNChangeStatus status) {
		return status.textStatus == Kind.MODIFIED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isTextConflicted(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isTextConflicted(SVNChangeStatus status) {
		return status.textStatus == Kind.CONFLICTED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isPropModified(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isPropModified(SVNChangeStatus status) {
		return status.propStatus == Kind.MODIFIED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isPropConflicted(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isPropConflicted(SVNChangeStatus status) {
		return status.propStatus == Kind.CONFLICTED;
	}

	/**
	 * @see org.tigris.subversion.svnclientadapter.utils.SVNStatusUtils#isReadyForCommit(org.tigris.subversion.svnclientadapter.ISVNStatus)
	 */
	public static boolean isReadyForCommit(SVNChangeStatus status) {
		return isTextModified(status) || isAdded(status) || isDeleted(status) || isReplaced(status)
				|| isPropModified(status) || isTextConflicted(status) || isPropConflicted(status)
				|| (!isManaged(status) && !isIgnored(status));
	}
}
