/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.findings.view;

import java.util.Arrays;
import java.util.List;

import org.conqat.ide.commons.ui.pref.StringListEditor;
import org.conqat.ide.commons.ui.pref.StringListEditorBase;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.ui.views.markers.FilterConfigurationArea;
import org.eclipse.ui.views.markers.MarkerFieldFilter;

import com.teamscale.ide.TeamscaleIDEActivator;

/**
 * Base class for category and group filter configuration areas. These are added
 * by the RCP to the contents of the 'Configure Contents' dialog for the view.
 */
public abstract class FieldFilterConfigurationBase extends FilterConfigurationArea {

	/** The title of the dialog to add a string. */
	private final String inputTitle;

	/** A string shown above the input field in the add dialog. */
	private final String inputCommand;

	/** The preference name that is used to store the list of strings. */
	private final String preferenceName;

	/** Label shown above the list. */
	private final String labelText;

	/** The editor widget for managing the list of filter strings. */
	private StringListEditor editor;

	/** Constructor. */
	public FieldFilterConfigurationBase(String inputTitle, String inputCommand, String preferenceName,
			String labelText) {
		this.inputTitle = inputTitle;
		this.inputCommand = inputCommand;
		this.preferenceName = preferenceName;
		this.labelText = labelText;
	}

	/** {@inheritDoc} */
	@Override
	public void apply(MarkerFieldFilter filter) {
		editor.store();
		if (filter instanceof FieldFilterBase) {
			((FieldFilterBase) filter).setFilteredValues(
					Arrays.asList(StringListEditorBase.split(editor.getPreferenceStore().getString(preferenceName))));
		}
	}

	/** {@inheritDoc} */
	@Override
	public void createContents(Composite parent) {
		editor = new StringListEditor(inputTitle, inputCommand, preferenceName, labelText, parent);
		editor.setPreferenceStore(TeamscaleIDEActivator.getDefault().getPreferenceStore());
	}

	/** {@inheritDoc} */
	@Override
	public void initialize(MarkerFieldFilter filter) {
		if (filter instanceof FieldFilterBase) {
			List<String> list = ((FieldFilterBase) filter).getFilteredValues();
			String[] stringArray = list.toArray(new String[list.size()]);
			editor.loadStrings(stringArray);
		}
	}
}