/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.findings.view;

import java.util.Comparator;

import org.eclipse.core.resources.IMarker;
import org.eclipse.ui.views.markers.MarkerField;
import org.eclipse.ui.views.markers.MarkerItem;

import com.google.common.collect.Range;
import com.teamscale.ide.findings.FindingsMarkerUtils;

/**
 * Marker field for the location. We use a custom implementation to allow for
 * proper sorting (default would be lexicographic).
 */
public class LocationField extends MarkerField {

	/** {@inheritDoc} */
	@Override
	public String getValue(MarkerItem item) {
		return item.getMarker().getAttribute(IMarker.LOCATION, "");
	}

	/** {@inheritDoc} */
	@Override
	public int compare(MarkerItem item1, MarkerItem item2) {
		String stringValue1 = getValue(item1);
		String stringValue2 = getValue(item2);
		if (stringValue1.equals("") || stringValue2.equals("")) {
			return stringValue1.compareTo(stringValue2);
		}
		Range<Integer> location1 = FindingsMarkerUtils.splitLocationString(stringValue1);
		Range<Integer> location2 = FindingsMarkerUtils.splitLocationString(stringValue2);

		return Comparator.comparingInt(Range<Integer>::lowerEndpoint).thenComparingInt(Range<Integer>::upperEndpoint)
				.compare(location1, location2);
	}
}
