/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package com.teamscale.ide.findings.view;

import org.eclipse.core.commands.AbstractHandler;
import org.eclipse.core.commands.ExecutionEvent;
import org.eclipse.ui.PlatformUI;

import com.teamscale.ide.eclipse.EclipseIds;

/**
 * A handler that initiates a reload of the findings by the Findings view.
 * 
 * This only works if the command is run with the view open. It wouldn't work,
 * e. g. if the command would be presented in the menu. However, we currently
 * only show the command as a view toolbar button, so the view is guaranteed to
 * be open.
 */
public class RefreshHandler extends AbstractHandler {

	@Override
	public Object execute(ExecutionEvent event) {
		FindingsMarkerView view = (FindingsMarkerView) PlatformUI.getWorkbench().getActiveWorkbenchWindow()
				.getActivePage().findView(EclipseIds.Parts.FINDINGS);
		if (view != null) {
			view.forceRefresh();
		}

		return null;
	}

}
