/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.properties;

import org.eclipse.core.resources.IProject;
import org.eclipse.core.runtime.jobs.JobChangeAdapter;

/**
 * Provides the functionality to do auto-mapping for a local project to a
 * Teamscale project.
 */
public class AutoMapping {

	/** The path to a file which is used to find the proper prefixes. */
	private final String path;

	/** The Teamscale server. */
	private final String servername;

	/** The corresponding project. */
	private final IProject project;

	/**
	 * Should the project property page be open automatically if the
	 * auto-mapping is not successful.
	 */
	private Boolean openPropertyPageIfFails = false;

	/** A project on the Teamscale server, can be <code>null</code>. */
	private final String teamscaleProject;

	/**
	 * Constructor.
	 *
	 * @param path
	 *            A path to a local resource, it can be <code>null</code>. If it
	 *            is <code>null</code>, then this job tries to find a source
	 *            file within the given project.
	 * 
	 *            The path is used to find a matching file on the Teamscale
	 *            server.
	 * 
	 * @param teamscaleProject
	 *            A project on the Teamscale server, can be <code>null</code>.
	 *            It it is <code>null</code>, then the job search every project
	 *            for matching mappings.
	 */
	public AutoMapping(IProject project, String servername, String path, String teamscaleProject) {
		this.project = project;
		this.servername = servername;
		this.path = path;
		this.teamscaleProject = teamscaleProject;
	}

	/** Constructor. */
	public AutoMapping(IProject project, String servername, String teamscaleProjcet) {
		this(project, servername, null, teamscaleProjcet);
	}

	/** Constructor. */
	public AutoMapping(IProject project, String path, boolean openPropertyPage) {
		this(project, null, path, null);
		this.openPropertyPageIfFails = openPropertyPage;
	}

	/** Tries to auto-map the local project to a teamscale project. */
	public void tryAutoMapping(JobChangeAdapter adapter) {
		AutoMappingJob job = new AutoMappingJob(servername, project, path,
				new AutoMappingResultHandler(project, openPropertyPageIfFails), teamscaleProject);

		job.addJobChangeListener(adapter);
		job.setUser(true);
		job.schedule();
	}
}
