/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.properties;

import java.util.ArrayList;
import java.util.Set;

import org.conqat.ide.commons.ui.jface.DialogUtils;
import org.eclipse.core.resources.IProject;
import org.eclipse.jface.dialogs.MessageDialog;
import org.eclipse.jface.viewers.LabelProvider;

import com.teamscale.ide.EclipseUtils;
import com.teamscale.ide.client.PrefixMappingRegistry;
import com.teamscale.ide.commons.model.PrefixMapping;
import com.teamscale.ide.eclipse.util.ui.WorkbenchUtils;

/**
 * This class handles the the auto-mapping result.
 */
public class AutoMappingResultHandler {

	/** The local project. */
	private final IProject project;

	/** Should the project property page be opened if the auto-mapping fails. */
	private final Boolean openPropertyPageIfFails;

	/** Constructor */
	public AutoMappingResultHandler(IProject project, Boolean openPropertyPageIfFails) {
		this.project = project;
		this.openPropertyPageIfFails = openPropertyPageIfFails;
	}

	/** Selects a possible mapping and sets the PrefixMappingRegistry. */
	public void handleMapping(Set<PrefixMapping> mappings, String servername) {
		if (mappings.isEmpty()) {
			showAutoMappingFailed();
			return;
		}

		PrefixMapping mapping = getMappingFromPossibleMappings(mappings);
		if (mapping == null) {
			return;
		}

		PrefixMappingRegistry registry = PrefixMappingRegistry.getInstance(project);

		registry.removeAll();
		registry.addMapping(mapping);
		registry.setTeamscaleProject(mapping.getProjectId());
		registry.setTeamscaleServer(servername);
	}

	/** MessageDialog to indicate failure. */
	private void showAutoMappingFailed() {
		PrefixMappingRegistry registry = PrefixMappingRegistry.getInstance(project);
		String message;
		if (registry.getMappings().isEmpty()) {
			registry.addMapping(new PrefixMapping("", ""));
			message = "Added default mapping instead.";
		} else {
			message = "Please set the prefixes manually.";
		}

		MessageDialog.openError(WorkbenchUtils.getActiveShell().orElse(null), "Auto-mapping was not successful",
				message);

		if (openPropertyPageIfFails) {
			EclipseUtils.openTeamscaleProjectPreferencePage(project);
		}
	}

	/**
	 * Select the mapping, if there is more than one, let the user select one.
	 */
	private static PrefixMapping getMappingFromPossibleMappings(Set<PrefixMapping> allPossibleMappings) {
		if (allPossibleMappings.size() > 1) {
			return DialogUtils.showListDialog(new ArrayList<>(allPossibleMappings),
					"Select a matching mapping for this project.", "Select a matching below.", new LabelProvider());
		} else if (allPossibleMappings.size() == 1) {
			return allPossibleMappings.iterator().next();
		}
		return null;
	}

}