/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 the ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package com.teamscale.ide.ui.images;

import org.eclipse.jface.resource.ImageDescriptor;
import org.eclipse.jface.resource.ImageRegistry;
import org.eclipse.swt.graphics.Image;

import com.google.common.base.Preconditions;
import com.teamscale.ide.TeamscaleIDEActivator;

/**
 * Enumeration that provides images used in the application. The image registry
 * provided by Eclipse is used to store images.
 * 
 */
public enum ETeamscaleImage {

	/** ID for the disabled status icon. */
	DISABLED,

	/** ID for the reachable status icon. */
	REACHABLE,

	/** ID for the mixed status icon. */
	MIXED,

	/** ID for the unreachable status icon. */
	UNREACHABLE,

	/** ID for the fetching disabled status icon. */
	FETCHING_DISABLED;

	/** Registers all images of this enumeration at the given registry. */
	public static void registerImages(ImageRegistry registry) {
		for (ETeamscaleImage image : values()) {
			String imageName = image.getImageName();
			ImageDescriptor descriptor = registry.getDescriptor(imageName);

			Preconditions.checkState(descriptor == null, "Image {} has already been registered", imageName);
			registry.put(imageName, TeamscaleIDEActivator.getImageDescriptor(image.getImagePath()));
		}
	}

	/** Returns the image registry from TeamscaleIDEActivator. */
	private static ImageRegistry getRegistry() {
		return TeamscaleIDEActivator.getDefault().getImageRegistry();
	}

	/** Returns the image for enumeration element. */
	public Image getImage() {
		return getRegistry().get(getImageName());
	}

	/** Returns the image descriptor for enumeration element. */
	public ImageDescriptor getImageDescriptor() {
		return getRegistry().getDescriptor(getImageName());
	}

	/** Returns the image name. */
	private String getImageName() {
		return name().toLowerCase();
	}

	/** Returns the path to the image. */
	private String getImagePath() {
		StringBuilder path = new StringBuilder("icons/");
		path.append(getImageName());
		path.append(".png");
		return path.toString();
	}
}
