package eu.cqse.check.framework.scanner.ambiguous_language;

/**
 * Searches for typical patterns of Matlab in the given file text.
 */
class MatlabLanguageDetector {

	/**
	 * Searches for typical patterns of Matlab in the given file text. Returns
	 * whether Matlab code was found.
	 */
	public static boolean containsLikelyMatlabCode(String fileContent) {
		String trimmedContent = fileContent.trim();
		if (trimmedContent.startsWith("%")) {
			// % is the start of a comment in matlab. In C-like languages it would be a
			// modulo operator (having it at the start of a file would be invalid syntax in
			// C-like languages).
			return true;
		}
		if (trimmedContent.startsWith("syms ")) {
			// syms is a matlab keyword that marks variables as "symbolic". Since this sets
			// the "working environment" of a matlab file, it is likely at the file begin.
			return true;
		}
		if (trimmedContent.contains("\n%")) {
			// % is the start of a comment in matlab. In C-like languages it would be a
			// modulo operator (having it at the start of a line would be really strange
			// formatting).
			return true;
		}
		return false;
	}
}
