/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.commons.util;

import java.awt.Color;
import java.io.IOException;

import org.conqat.lib.commons.color.ColorUtils;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.module.SimpleModule;

/**
 * Jackson module which supports serialization and deserialization of
 * {@link Color} objects to their hex string representation and back.
 */
public class ColorSerializationModule extends SimpleModule {

	ColorSerializationModule() {
		addSerializer(Color.class, new ColorSerializer());
		addDeserializer(Color.class, new ColorDeserializer());
	}

	/**
	 * Serializer for {@link Color} objects represented as "#001122".
	 */
	private static class ColorSerializer extends JsonSerializer<Color> {

		@Override
		public void serialize(Color value, JsonGenerator gen, SerializerProvider serializers) throws IOException {
			gen.writeString(ColorUtils.toHtmlString(value));
		}
	}

	/**
	 * Deserializer for {@link Color} objects represented as "#001122".
	 */
	private static class ColorDeserializer extends JsonDeserializer<Color> {

		@Override
		public Color deserialize(JsonParser p, DeserializationContext ctxt) throws IOException {
			String root = p.getText();
			return ColorUtils.fromString(root);
		}
	}

}
