package org.conqat.engine.commons.util;

import java.io.IOException;
import java.util.List;
import java.util.stream.Collectors;

import org.conqat.lib.commons.collections.IntList;
import org.conqat.lib.commons.string.LineRange;
import org.conqat.lib.commons.string.LineRangeStringParser;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.ser.std.StdSerializer;

/**
 * Custom Serializer to serialize {@link IntList} to string separated line
 * ranges. See {@link LineRangeStringParser} for more details.
 */
public class LineRangeSerializer extends StdSerializer<IntList> {

	private static final long serialVersionUID = -9191867553019031697L;

	public LineRangeSerializer() {
		this(null);
	}

	private LineRangeSerializer(Class<IntList> t) {
		super(t);
	}

	@Override
	public void serialize(IntList value, JsonGenerator jsonGen, SerializerProvider provider) throws IOException {
		List<LineRange> compactLineRanges = LineRangeStringParser.compactifyToRanges(value);
		String concatenatedCompactLineRanges = compactLineRanges.stream().map(Object::toString)
				.collect(Collectors.joining(","));
		jsonGen.writeString(concatenatedCompactLineRanges);
	}
}
