/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.commons.util;

import java.io.IOException;
import java.util.HashMap;
import java.util.Map;
import java.util.Set;

import org.conqat.lib.commons.collections.SetMap;

import com.fasterxml.jackson.core.JsonGenerator;
import com.fasterxml.jackson.core.JsonParser;
import com.fasterxml.jackson.databind.DeserializationContext;
import com.fasterxml.jackson.databind.JsonDeserializer;
import com.fasterxml.jackson.databind.JsonSerializer;
import com.fasterxml.jackson.databind.SerializerProvider;
import com.fasterxml.jackson.databind.module.SimpleModule;

/**
 * Jackson module which supports serialization and deserialization of
 * {@link SetMap} object and back.
 */
public class SetMapSerializationModule extends SimpleModule {

	private static final long serialVersionUID = 1L;

	SetMapSerializationModule() {
		addSerializer(SetMap.class, new SetMapSerializer());
		addDeserializer(SetMap.class, new SetMapDeserializer());
	}

	/** Serializer for {@link SetMap} objects. */
	private static class SetMapSerializer<K, V> extends JsonSerializer<SetMap<K, V>> {

		@Override
		public void serialize(SetMap<K, V> value, JsonGenerator generator, SerializerProvider serializers)
				throws IOException {
			HashMap<K, Set<V>> map = new HashMap<>();
			for (Map.Entry<K, Set<V>> entry : value.entrySet()) {
				map.put(entry.getKey(), entry.getValue());
			}
			generator.writeObject(map);
		}
	}

	/** Deserializer for {@link SetMap} objects. */
	private static class SetMapDeserializer extends JsonDeserializer<SetMap> {

		@Override
		public SetMap deserialize(JsonParser parser, DeserializationContext ctx) throws IOException {
			HashMap root = parser.getCodec().readValue(parser, HashMap.class);
			return new SetMap<>(root);
		}
	}
}
