/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.index.shared;

import java.util.ArrayList;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Summary of findings for a container or element. Holds a category name and a
 * list of {@link FindingsSummaryGroupInfo}s.
 */
public class FindingsSummaryCategoryInfo extends FindingsSummaryCountInfoBase {

	private static final long serialVersionUID = 1L;

	/** The name of the JSON property name for {@link #categoryName}. */
	private static final String CATEGORY_NAME_PROPERTY = "categoryName";

	/** The name of the finding category */
	@JsonProperty(CATEGORY_NAME_PROPERTY)
	private final String categoryName;

	/** The finding group infos */
	@JsonProperty("groupInfos")
	private final List<FindingsSummaryGroupInfo> groupInfos = new ArrayList<>();

	@JsonCreator
	public FindingsSummaryCategoryInfo(@JsonProperty(CATEGORY_NAME_PROPERTY) String categoryName) {
		this.categoryName = categoryName;
	}

	/** Returns the finding category. */
	public String getCategoryName() {
		return categoryName;
	}

	/** Returns the group infos. */
	public List<FindingsSummaryGroupInfo> getGroupInfos() {
		return groupInfos;
	}

	/** Adds the given group info to this category info. */
	public void addGroupInfo(FindingsSummaryGroupInfo groupInfo) {
		count += groupInfo.getCount();
		countRed += groupInfo.getCountRed();
		this.groupInfos.add(groupInfo);
	}

}
