/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.index.shared;

import java.io.Serializable;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/** Holds how many findings exist for a given guideline (e.g. AUTOSAR C++14). */
public class FindingsSummaryGuidelineInfo implements Serializable {

	private static final long serialVersionUID = 1L;

	private static final String GUIDELINE_NAME_PROPERTY = "guidelineName";
	private static final String RULE_INFOS_PROPERTY = "ruleInfos";

	@JsonProperty(GUIDELINE_NAME_PROPERTY)
	private final String guidelineName;

	@JsonProperty(RULE_INFOS_PROPERTY)
	private final List<FindingsSummaryGuidelineRuleInfo> ruleInfos;

	@JsonCreator
	public FindingsSummaryGuidelineInfo(@JsonProperty(GUIDELINE_NAME_PROPERTY) String guidelineName,
			@JsonProperty(RULE_INFOS_PROPERTY) List<FindingsSummaryGuidelineRuleInfo> ruleInfos) {
		this.guidelineName = guidelineName;
		this.ruleInfos = ruleInfos;
	}

}
