/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.index.shared;

import java.io.Serializable;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Provides the finding count regarding the findings schema (categories, groups,
 * rules) and guidelines.
 */
public class FindingsSummaryInfo implements Serializable {

	private static final long serialVersionUID = 1L;

	private static final String CATEGORY_INFOS_PROPERTY = "categoryInfos";
	private static final String GUIDELINE_INFOS_PROPERTY = "guidelineInfos";

	@JsonProperty(CATEGORY_INFOS_PROPERTY)
	private final List<FindingsSummaryCategoryInfo> categoryInfos;

	@JsonProperty(GUIDELINE_INFOS_PROPERTY)
	private final List<FindingsSummaryGuidelineInfo> guidelineInfos;

	@JsonCreator
	public FindingsSummaryInfo(@JsonProperty(CATEGORY_INFOS_PROPERTY) List<FindingsSummaryCategoryInfo> categoryInfos,
			@JsonProperty(GUIDELINE_INFOS_PROPERTY) List<FindingsSummaryGuidelineInfo> guidelineInfos) {
		this.categoryInfos = categoryInfos;
		this.guidelineInfos = guidelineInfos;
	}

	public List<FindingsSummaryCategoryInfo> getCategoryInfos() {
		return categoryInfos;
	}
}
