/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.index.shared;

import java.io.Serializable;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Holds a finding typeId name (i.e. finding rule name) along with its number of
 * corresponding findings.
 */
public class FindingsSummaryTypeIdInfo extends FindingsSummaryCountInfoBase implements Serializable {

	/** Version for serialization */
	private static final long serialVersionUID = 1;

	private static final String NAME_PROPERTY = "name";

	/** The name of the JSON property name for {@link #typeIdName}. */
	private static final String TYPE_ID_NAME_PROPERTY = "typeIdName";

	/** The name of the JSON property name for {@link #count}. */
	private static final String COUNT_PROPERTY = "count";

	/** The name of the JSON property name for {@link #countRed}. */
	private static final String COUNT_RED_PROPERTY = "countRed";

	/** The name of the finding typeId */
	@JsonProperty(TYPE_ID_NAME_PROPERTY)
	private final String typeIdName;

	@JsonProperty(NAME_PROPERTY)
	private final String name;

	/** Constructor */
	@JsonCreator
	public FindingsSummaryTypeIdInfo(@JsonProperty(NAME_PROPERTY) String name,
			@JsonProperty(TYPE_ID_NAME_PROPERTY) String typeIdName, @JsonProperty(COUNT_PROPERTY) int count,
			@JsonProperty(COUNT_RED_PROPERTY) int countRed) {
		this.name = name;
		this.typeIdName = typeIdName;
		this.count = count;
		this.countRed = countRed;
	}

	/** Returns the finding typeId. */
	public String getTypeId() {
		return typeIdName;
	}

}
