package org.conqat.engine.index.shared;

import com.fasterxml.jackson.annotation.JsonProperty;

import eu.cqse.check.framework.scanner.ELanguage;

/**
 * Helper class to store the language of a file and whether it was chosen based
 * on a user defined language mapping specified in the project settings or not.
 */
public class LanguageInfo {

	/** The identified language. */
	private final ELanguage language;

	/**
	 * Whether the language was chosen based on a user defined language mapping
	 * specified in the project settings.
	 */
	private final boolean isFileLanguageSetByUser;

	public LanguageInfo(@JsonProperty("language") ELanguage language,
			@JsonProperty("isFileLanguageSetByUser") boolean isFileLanguageSetByUser) {
		this.language = language;
		this.isFileLanguageSetByUser = isFileLanguageSetByUser;
	}

	/** @see #language */
	public ELanguage getLanguage() {
		return language;
	}

	/** @see #isFileLanguageSetByUser */
	public boolean getIsFileLanguageSetByUser() {
		return isFileLanguageSetByUser;
	}
}