/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.sourcecode.coverage;

import java.util.List;
import java.util.function.Function;

import org.conqat.lib.commons.js_export.ExportToTypeScript;

/**
 * Information on how a line was covered.
 */
@ExportToTypeScript
public enum ELineCoverage {

	/** The line was not covered at all */
	NOT_COVERED(LineCoverageInfo::getUncoveredLines),

	/** The line was partially covered */
	PARTIALLY_COVERED(LineCoverageInfo::getPartiallyCoveredLines),

	/** The line was fully covered */
	FULLY_COVERED(LineCoverageInfo::getFullyCoveredLines);

	private final Function<LineCoverageInfo, List<Integer>> relevantLinesFunction;

	private ELineCoverage(Function<LineCoverageInfo, List<Integer>> relevantLinesFunction) {
		this.relevantLinesFunction = relevantLinesFunction;
	}

	/**
	 * Returns the relevant lines that are covered with this {@link ELineCoverage}
	 * type
	 */
	public List<Integer> getRelevantLines(LineCoverageInfo lineCoverageInfo) {
		return relevantLinesFunction.apply(lineCoverageInfo);
	}

}
