package org.conqat.engine.sourcecode.coverage;

import org.conqat.lib.commons.test.IndexValueClass;
import java.io.Serializable;

import org.conqat.lib.commons.js_export.ExportToTypeScript;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * An MC/DC condition necessary to meet the MC/DC criterion consisting of a
 * textual description and the information whether it was fulfilled.
 */
@ExportToTypeScript
@IndexValueClass(containedInBackup = true)
public class McDcCondition implements Serializable {

	private static final long serialVersionUID = 1L;

	@JsonProperty("description")
	private final String description;

	@JsonProperty("fulfilled")
	private boolean fulfilled;

	@JsonCreator
	public McDcCondition(@JsonProperty("fulfilled") boolean fulfilled,
			@JsonProperty("description") String description) {
		this.fulfilled = fulfilled;
		this.description = description;
	}

	/** @see #description */
	public String getDescription() {
		return description;
	}

	/** @see #fulfilled */
	public boolean isFulfilled() {
		return fulfilled;
	}

	/** @see #fulfilled */
	public void setFulfilled(boolean fulfilled) {
		this.fulfilled = fulfilled;
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		StringBuilder result = new StringBuilder();
		if (fulfilled) {
			result.append("+");
		} else {
			result.append("-");
		}
		result.append(" (" + description + ")");
		return result.toString();
	}
}