package org.conqat.engine.sourcecode.coverage.testwise_coverage;

import org.conqat.lib.commons.collections.IntList;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Holds coverage of a single file.
 *
 * This class is a DTO used to deserialize testwise coverage reports. Field
 * names and structure may not be changed.
 */
public class FileCoverage {

	/** The name of the JSON property name for {@link #fileName}. */
	private static final String FILENAME_PROPERTY = "fileName";

	/** The name of the JSON property name for {@link #coveredLines}. */
	private static final String COVERED_LINES_PROPERTY = "coveredLines";

	/** The name of the file. */
	@JsonProperty(FILENAME_PROPERTY)
	public final String fileName;

	/** A list of line ranges that have been covered. */
	@JsonProperty(COVERED_LINES_PROPERTY)
	public final IntList coveredLines;

	@JsonCreator
	public FileCoverage(@JsonProperty(FILENAME_PROPERTY) String fileName,
			@JsonProperty(COVERED_LINES_PROPERTY) IntList coveredLines) {
		this.fileName = fileName;
		this.coveredLines = coveredLines;
	}
}
