package org.conqat.engine.sourcecode.coverage.testwise_coverage;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Container for {@link FileCoverage}s of the same path.
 *
 * This class is a DTO used to deserialize testwise coverage reports. Field
 * names and structure may not be changed.
 */
public class PathCoverage {

	/** The name of the JSON property name for {@link #path}. */
	private static final String PATH_PROPERTY = "path";

	/** The name of the JSON property name for {@link #files}. */
	private static final String FILES_PROPERTY = "files";

	/** File system path. */
	@JsonProperty(PATH_PROPERTY)
	public final String path;

	/** Files with coverage. */
	@JsonProperty(FILES_PROPERTY)
	public final List<FileCoverage> files;

	@JsonCreator
	public PathCoverage(@JsonProperty(PATH_PROPERTY) String path,
			@JsonProperty(FILES_PROPERTY) List<FileCoverage> files) {
		this.path = path;
		this.files = files;
	}
}
