/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.engine.sourcecode.coverage.testwise_coverage;

import java.util.List;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * A report containing testwise coverage. Unlike {@link TestwiseCoverageReport},
 * this does not contain simple line coverage but one raw, unparsed test report
 * per test case.
 */
public class RawTestwiseReport {

	/**
	 * The tests for which this report contains coverage. For each tests, the
	 * respective coverage report is stored in {@link TestInfo#content}
	 */
	@JsonProperty("tests")
	public final List<TestInfo> tests;

	/**
	 * The format of the contained coverage reports.
	 */
	@JsonProperty("format")
	public final String format;

	/**
	 * Whether this testwise report is partial. See
	 * {@link TestwiseCoverageReport#isPartial()}.
	 */
	@JsonProperty("partial")
	public final boolean partial;

	@JsonCreator
	public RawTestwiseReport(@JsonProperty("tests") List<TestInfo> tests, @JsonProperty("format") String format,
			@JsonProperty("partial") boolean partial) {
		this.tests = tests;
		this.format = format;
		this.partial = partial;
	}
}