package org.conqat.engine.sourcecode.coverage.testwise_coverage;

import java.util.ArrayList;
import java.util.List;

import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Container for coverage produced by multiple tests.
 *
 * This class is a DTO used to deserialize testwise coverage reports. Field
 * names and structure may not be changed.
 */
public class TestwiseCoverageReport {

	/**
	 * Version number for the testwise coverage report. Defaults to version 1, which
	 * represents the old testwise coverage report format. The current version is 2.
	 * This field is only present in coverage reports of version 2+.
	 */
	@JsonProperty("version")
	private Integer version = 1;

	/**
	 * If set to `true` the set of tests contained in the report don't represent the
	 * full set of tests within a partition. These tests are added or updated in
	 * Teamscale, but no tests or executable units that are missing in the report
	 * will be deleted. If not provided defaults to `false`. This field is
	 * considered for reports of all versions.
	 */
	@JsonProperty("partial")
	private boolean partial = false;

	/**
	 * Optional timestamp in milliseconds for the point in time when the report was
	 * created. Present in reports of version 2+.
	 */
	@JsonProperty("creationTimestamp")
	public final Long creationTimestamp = null;

	/**
	 * Property containing detailed information about covered files. This usually
	 * includes the path and the coverable lines as produced by an external coverage
	 * tool. File infos are referenced elsewhere in the report by their index in the
	 * array. Present in reports of version 2+.
	 */
	@JsonProperty("files")
	public final List<FileInfo> files = new ArrayList<>();

	/**
	 * The tests contained in the report. They are independent of an executable
	 * unit. Present in reports of all versions.
	 */
	@JsonProperty("tests")
	public final List<TestInfo> tests = new ArrayList<>();

	/**
	 * Represents a set of tests that is executed together. Present in reports of
	 * version 2+.
	 */
	@JsonProperty("executionUnits")
	public final List<ExecutionUnitInfo> executionUnits = new ArrayList<>();

	public TestwiseCoverageReport() {
	}

	public TestwiseCoverageReport(Integer version, boolean partial, List<FileInfo> files, List<TestInfo> tests) {
		this.version = version;
		this.partial = partial;
		this.files.addAll(files);
		this.tests.addAll(tests);
	}

	public Integer getVersion() {
		return version;
	}

	public boolean isPartial() {
		return partial;
	}

	public void setPartial(boolean partial) {
		this.partial = partial;
	}
}
