/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.editor;

import java.util.Collections;

import org.eclipse.core.resources.IFile;
import org.eclipse.ui.IEditorInput;
import org.eclipse.ui.IEditorPart;
import org.eclipse.ui.ide.ResourceUtil;

import com.teamscale.ide.commons.findings.tasks.FetchFindingsTask;
import com.teamscale.ide.commons.model.ResourceReference;
import com.teamscale.ide.commons.notification.ENotificationCause;
import com.teamscale.ide.commons.plugin.IServiceRegistry;
import com.teamscale.ide.commons.plugin.services.ITaskExecutor;
import com.teamscale.ide.eclipse.IUiPreferences;
import com.teamscale.ide.eclipse.model.ResourceReferences;
import com.teamscale.ide.eclipse.plugin.EclipseServiceRegistry;

/**
 * Offers helper methods for editor handling.
 * 
 * This class handles two dimensions: (1) files can be in the workspace or
 * outside, (2) editors can be internal or outside. Only a subset of all
 * possible combinations is currently supported.
 */
public class EditorUtils {

	/**
	 * Returns the {@link IFile} that is open in this {@link IEditorPart} or
	 * <code>null</code> if there is no applicable file.
	 * 
	 */
	public static IFile getEditorFile(IEditorPart editorPart) {
		return getEditorFile(editorPart.getEditorInput());
	}

	/**
	 * Returns the {@link IFile} that is open in this {@link IEditorInput} or
	 * <code>null</code> if there is no applicable file.
	 * 
	 */
	public static IFile getEditorFile(IEditorInput editorInput) {
		return ResourceUtil.getFile(editorInput);
	}

	/**
	 * Executes a {@link FetchFindingsTask} for the given editor if the referenced
	 * file of the editor can be mapped to a {@link ResourceReference}.
	 */
	public static void fetchFindingsForEditor(IEditorPart editor, ENotificationCause cause) {
		if (editor == null) {
			return;
		}

		IFile file = getEditorFile(editor);
		if (file == null) {
			return;
		}

		ResourceReference resourceReference = ResourceReferences.fromIResource(file).orElse(null);
		if (resourceReference == null) {
			return;
		}

		IServiceRegistry serviceRegistry = EclipseServiceRegistry.getInstance();
		serviceRegistry.getService(ITaskExecutor.class)
				.execute(FetchFindingsTask.createFetchTask(serviceRegistry, cause,
						Collections.singleton(resourceReference),
						IUiPreferences.getInstance().isAutomaticPreCommitAnalysisEnabled()));
	}
}
