/*-------------------------------------------------------------------------+
|                                                                          |
| Copyright 2005-2011 The ConQAT Project                                   |
|                                                                          |
| Licensed under the Apache License, Version 2.0 (the "License");          |
| you may not use this file except in compliance with the License.         |
| You may obtain a copy of the License at                                  |
|                                                                          |
|    http://www.apache.org/licenses/LICENSE-2.0                            |
|                                                                          |
| Unless required by applicable law or agreed to in writing, software      |
| distributed under the License is distributed on an "AS IS" BASIS,        |
| WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. |
| See the License for the specific language governing permissions and      |
| limitations under the License.                                           |
+-------------------------------------------------------------------------*/
package org.conqat.ide.commons.ui.jface;

import java.util.List;

import org.eclipse.jface.viewers.ILabelProvider;
import org.eclipse.jface.viewers.LabelProvider;
import org.eclipse.jface.window.Window;
import org.eclipse.swt.widgets.Display;
import org.eclipse.swt.widgets.Shell;
import org.eclipse.ui.dialogs.ElementListSelectionDialog;

/**
 * Utility methods dealing with dialogs.
 * 
 * 
 * @author deissenb
 */
public class DialogUtils {

	/**
	 * This method shows a dialog that allows to select from a list.
	 * 
	 * @param <T>
	 *            type of elements shown in the list.
	 * @param elements
	 *            elements to select from
	 * @param title
	 *            dialog title
	 * @param message
	 *            dialog message
	 * @param labelProvider
	 *            label provider for the list. Use {@link LabelProvider} if
	 *            <code>toString()</code> is sufficient as label.
	 */
	@SuppressWarnings("unchecked")
	public static <T> T showListDialog(List<T> elements, String title, String message, ILabelProvider labelProvider) {
		ElementListSelectionDialog dialog = initializeDialog(elements, title, message, labelProvider);
		dialog.setMultipleSelection(false);
		int result = dialog.open();

		if (result == Window.OK) {
			return (T) dialog.getFirstResult();
		}
		return null;
	}

	/**
	 * This method initializes the dialog.
	 * 
	 * @param <T>
	 *            type of elements shown in the list.
	 * @param elements
	 *            elements to select from
	 * @param title
	 *            dialog title
	 * @param message
	 *            dialog message
	 * @param labelProvider
	 *            label provider for the list. Use {@link LabelProvider} if
	 *            <code>toString()</code> is sufficient as label.
	 */
	private static <T> ElementListSelectionDialog initializeDialog(List<T> elements, String title, String message,
			ILabelProvider labelProvider) {
		Shell shell = Display.getCurrent().getActiveShell();
		ElementListSelectionDialog dialog = new ElementListSelectionDialog(shell, labelProvider);
		dialog.setElements(elements.toArray());
		dialog.setTitle(title);
		dialog.setMessage(message);
		return dialog;
	}
}
