/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.collections;

/**
 * Offers the ability to perform lookahead on an ordered collection.
 */
public interface ILookahead<Data, X extends Exception> {

	/**
	 * Returned elements remain in the underlying data structure and are still
	 * accessible.
	 * 
	 * @param index
	 *            Number of elements that are looked ahead
	 * 
	 * @return Element at index, or null, if the provider doesn't contain that
	 *         many elements anymore
	 */
	public Data lookahead(int index) throws X;
}
