package org.conqat.lib.commons.collections;

import java.util.function.Function;
import java.util.function.Supplier;
import java.util.stream.Collector;
import java.util.stream.Collectors;

/** A stream {@link Collector} type to create {@link ListMap}s. */
public class ListMapCollector<T, K, V> extends CollectionMapCollectorBase<T, K, V, ListMap<K, V>> {

	private ListMapCollector(Function<T, K> keyMapper, Function<T, V> valueMapper) {
		super(keyMapper, valueMapper);
	}

	@Override
	public Supplier<ListMap<K, V>> supplier() {
		return ListMap::new;
	}

	/**
	 * Collects the stream into a new {@link ListMap} where stream objects are
	 * mapped to {@link ListMap} keys by the given keyMapper and to {@link ListMap}
	 * values by the given valueMapper.
	 */
	public static <T, K, V> ListMapCollector<T, K, V> collect(Function<T, K> keyMapper, Function<T, V> valueMapper) {
		return new ListMapCollector<>(keyMapper, valueMapper);
	}

	/**
	 * Collects the stream into a new {@link ListMap}, grouping stream objects by
	 * the given keyMapper. This works identically to {@link Collectors#groupingBy}.
	 */
	public static <T, K> ListMapCollector<T, K, T> groupingBy(Function<T, K> keyMapper) {
		return new ListMapCollector<>(keyMapper, Function.identity());
	}
}
