/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.collections;

import java.util.AbstractSet;
import java.util.Iterator;
import java.util.Map;

/** Base class for set implementations based on a backing set. */
public abstract class MapBackedSetBase<E> extends AbstractSet<E> {

	/** Dummy object for the map. */
	private static final Object PRESENT = new Object();

	/** The map that actually stores the values. */
	private final Map<E, Object> map;

	protected MapBackedSetBase(Map<E, Object> map) {
		this.map = map;
	}

	@Override
	public boolean add(E o) {
		return map.put(o, PRESENT) == null;
	}

	@Override
	public void clear() {
		map.clear();
	}

	@Override
	public boolean contains(Object o) {
		return map.containsKey(o);
	}

	@Override
	public boolean isEmpty() {
		return map.isEmpty();
	}

	@Override
	public Iterator<E> iterator() {
		return map.keySet().iterator();
	}

	@Override
	public boolean remove(Object o) {
		return map.remove(o) == PRESENT;
	}

	@Override
	public int size() {
		return map.size();
	}
}
