/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.collections;

import java.util.function.Function;
import java.util.function.Supplier;
import java.util.stream.Collector;
import java.util.stream.Collectors;

/** A stream {@link Collector} type to create {@link SetMap}s. */
public class SetMapCollector<T, K, V> extends CollectionMapCollectorBase<T, K, V, SetMap<K, V>> {

	private SetMapCollector(Function<T, K> keyMapper, Function<T, V> valueMapper) {
		super(keyMapper, valueMapper);
	}

	@Override
	public Supplier<SetMap<K, V>> supplier() {
		return SetMap::new;
	}

	/**
	 * Collects the stream into a new {@link SetMap} where stream objects are mapped
	 * to {@link SetMap} keys by the given keyMapper and to {@link SetMap} values by
	 * the given valueMapper.
	 */
	public static <T, K, V> SetMapCollector<T, K, V> collect(Function<T, K> keyMapper, Function<T, V> valueMapper) {
		return new SetMapCollector<>(keyMapper, valueMapper);
	}

	/**
	 * Collects the stream into a new {@link SetMap}, grouping stream objects by the
	 * given keyMapper. This works identically to {@link Collectors#groupingBy}.
	 */
	public static <T, K> SetMapCollector<T, K, T> groupingBy(Function<T, K> keyMapper) {
		return new SetMapCollector<>(keyMapper, Function.identity());
	}
}