/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.collections;

import java.util.Arrays;

/** Wraps an {@link IntList} and sorts it to allow for fast range queries. */
public class SortedIntList {

	private final IntList list;

	public SortedIntList(IntList list) {
		Arrays.sort(list.array);
		this.list = list;
	}

	/**
	 * Returns true if any of the numbers in the given range (start and end
	 * included) are contained in the list.
	 */
	public boolean containsAnyOfRange(int start, int end) {
		int insertStart = Arrays.binarySearch(list.array, start);
		if (insertStart > 0) {
			return true;
		}
		int nextBiggerItemIndex = -insertStart - 1;
		if (list.array.length == nextBiggerItemIndex) {
			return false;
		}
		return list.array[nextBiggerItemIndex] <= end;
	}
}
