/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.diff;

/**
 * Class describing a substring of the diffed text as used for the diff
 * algorithms.
 */
public class TextChunk {

	/** Start offset of the text (inclusive, 0-based). */
	/* package */final int startOffset;

	/** End offset of the text (exclusive, 0-based). */
	/* package */final int endOffset;

	/** Start offset of the text (inclusive, 1-based). */
	/* package */final int startLine;

	/** End offset of the text (exclusive, 1-based). */
	/* package */final int endLine;

	/** Text used for comparison of the chunk. */
	private final String comparisonText;

	/** Constructor. */
	public TextChunk(int startOffset, int endOffset, int startLine, int endLine, String comparisonText) {
		this.startOffset = startOffset;
		this.endOffset = endOffset;
		this.startLine = startLine;
		this.endLine = endLine;
		this.comparisonText = comparisonText;
	}

	/** {@inheritDoc} */
	@Override
	public int hashCode() {
		return comparisonText.hashCode();
	}

	/** {@inheritDoc} */
	@Override
	public boolean equals(Object other) {
		return ((TextChunk) other).comparisonText.equals(comparisonText);
	}

	/** {@inheritDoc} */
	@Override
	public String toString() {
		return "\"" + comparisonText + "\" (lines: " + startLine + "-" + endLine + ", offsets: " + startOffset + "-"
				+ endOffset + ")";
	}
}
