/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.function;

import java.util.function.Function;

/**
 * This interface is the same as {@link Function}, except it allows throwing a
 * checked exception.
 */
@FunctionalInterface
public interface FunctionWithException<T, R, E extends Exception> {

	/**
	 * Applies this function to the given argument.
	 *
	 * @param t
	 *            the function argument
	 * @return the function result
	 */
	R apply(T t) throws E;

	/**
	 * Returns a function that always returns its input argument.
	 *
	 * @param <T>
	 *            the type of the input and output objects to the function
	 * @return a function that always returns its input argument
	 */
	static <T, E extends Exception> FunctionWithException<T, T, E> identity() {
		return t -> t;
	}

}
