/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.function;

/**
 * Implementation class for
 * {@link SupplierWithException#memoize(SupplierWithException)}
 */
/* package */ final class MemoizingSupplierWithException<T, E extends Exception>
		implements SupplierWithException<T, E> {

	private SupplierWithException<T, E> supplier;
	private T value;

	public MemoizingSupplierWithException(SupplierWithException<T, E> supplier) {
		this.supplier = supplier;
	}

	@Override
	public synchronized T get() throws E {
		if (supplier != null) {
			value = supplier.get();
			supplier = null;
		}
		return value;
	}
}
