/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.function;

import java.util.concurrent.Callable;

/** Functional interface for {@link Runnable}s which may throw exceptions. */
@FunctionalInterface
public interface RunnableWithException<E extends Exception> {

	/** An empty runnable. */
	static <E extends Exception> RunnableWithException<E> empty() {
		return () -> {
			// does nothing
		};
	}

	/** Run method performing actions that may throw an exception. */
	void run() throws E;

	/**
	 * @return provided {@code runnable} as {@link Callable}
	 */
	static Callable<Void> asCallable(RunnableWithException<?> runnable) {
		return () -> {
			runnable.run();
			return null;
		};
	}
}