/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.graph;

import org.conqat.lib.commons.string.StringUtils;

/**
 * Exception indicating problems while invoking graphviz programs.
 */
public class GraphvizException extends Exception {

	/** Version used for serialization. */
	private static final long serialVersionUID = 1;

	/** DOT error output. */
	private final String output;

	/**
	 * Create new exception. This is package visible as only classes from this
	 * package may create the excpetion.
	 * 
	 * @param output
	 *            the error output generated by DOT. Its first line is used a
	 *            exception message.
	 */
	/* package */ GraphvizException(String output) {
		super(StringUtils.getFirstLine(output));
		this.output = output;
	}

	/** Get DOT's original output. */
	public String getOutput() {
		return output;
	}
}