/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.region;

import org.conqat.lib.commons.test.IndexValueClass;
import org.conqat.lib.commons.js_export.ExportToTypeScript;

import com.fasterxml.jackson.annotation.JsonCreator;
import com.fasterxml.jackson.annotation.JsonProperty;

/**
 * Marker class used in code that needs to work with both offset- and line-based
 * regions to avoid confusing them.
 * 
 * Lines are inclusive (both start and end) and 1-based.
 * 
 * @see OffsetBasedRegion
 */
@ExportToTypeScript
@IndexValueClass(containedInBackup = true)
public class LineBasedRegion extends SimpleRegion {

	/** Version for serialization. */
	private static final long serialVersionUID = 1;

	@JsonCreator
	public LineBasedRegion(@JsonProperty(START_PROPERTY) int start, @JsonProperty(END_PROPERTY) int end) {
		super(start, end);
	}

}
