/*
 * Copyright (c) CQSE GmbH
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.conqat.lib.commons.resources;

import java.io.IOException;

/**
 * Exception that signals that either loading a resource from the classpath or
 * listing neighbouring resources for a given class file failed.
 */
public class ResourceException extends RuntimeException {

	private static final long serialVersionUID = 1L;

	private ResourceException(String message, IOException cause) {
		super(message, cause);
	}

	/**
	 * Constructs a {@link ResourceException} for when loading a resource failed.
	 */
	public static ResourceException newLoadFailed(Resource resource, IOException e) {
		return new ResourceException("Failed to read resource " + resource.getAbsolutePath(), e);
	}

	/**
	 * Constructs a {@link ResourceException} for when a native library could not be
	 * extracted.
	 */
	public static ResourceException nativeLibraryExtractionFailed(String libraryName, IOException cause) {
		return new ResourceException(String.format("Could not extract native library %s", libraryName), cause);
	}
}
